from ..UtilityAndView.abaqusConstants import *


class Leaf:
    """Leaf objects are used to specify the items in a display group. Leaf objects are
    constructed as temporary objects, which are then used as arguments to DisplayGroup
    commands.
    Leaf objects have similarities to Set objects; however, Leaf objects are evaluated when
    the DisplayGroup expression is evaluated, and they can have SymbolicConstant values
    (which are also evaluated when the DisplayGroup expression is evaluated).

    .. note:: 
        This object can be accessed by:

        .. code-block:: python

            import displayGroupMdbToolset
            import displayGroupOdbToolset
    """

    #: A SymbolicConstant specifying the leaf type. Possible values are EMPTY_LEAF,
    #: DEFAULT_MODEL, ALL_ELEMENTS, ALL_NODES, and ALL_SURFACES.
    leafType: SymbolicConstant

    def __init__(self, leafType: SymbolicConstant):
        """This method creates a Leaf object.

        .. note:: 
            This function can be accessed by:

            .. code-block:: python

                Leaf

        Parameters
        ----------
        leafType
            A SymbolicConstant specifying the leaf type. Possible values are EMPTY_LEAF,
            DEFAULT_MODEL, ALL_ELEMENTS, ALL_NODES, and ALL_SURFACES.

        Returns
        -------
        Leaf
            A :py:class:`~abaqus.DisplayGroup.Leaf.Leaf` object.
        """
        ...



import typing

from ..UtilityAndView.abaqusConstants import *


class HistoryOutputRequestState:
    """The HistoryOutputRequestState object stores the propagating data of a History output
    request current in a step. One instance of this object is created internally by the
    HistoryOutputRequest object for each step. The instance is also deleted internally by
    the HistoryOutputRequest object.
    The HistoryOutputRequestState object has no constructor or methods.

    .. note:: 
        This object can be accessed by:

        .. code-block:: python

            import step
            mdb.models[name].steps[name].historyOutputRequestState[name]
    """

    #: A SymbolicConstant specifying the propagation state of the history output request
    #: variables. Possible values are UNSET, SET, and UNCHANGED.
    variablesState: SymbolicConstant = None

    #: The SymbolicConstant LAST_INCREMENT or an Int specifying the output frequency in
    #: increments. The default value is 1.
    frequency: SymbolicConstant = 1

    #: A SymbolicConstant specifying the propagation state of the history output request
    #: frequency. Possible values are UNSET, SET, and UNCHANGED.
    frequencyState: SymbolicConstant = None

    #: A SymbolicConstant specifying the propagation state of the history output request modes.
    #: Possible values are UNSET, SET, and UNCHANGED.
    modesState: SymbolicConstant = None

    #: The SymbolicConstant EVERY_TIME_INCREMENT or a Float specifying the time interval at
    #: which the output states are to be written. The default value is EVERY_TIME_INCREMENT.
    timeInterval: typing.Union[SymbolicConstant, float] = EVERY_TIME_INCREMENT

    #: A SymbolicConstant specifying the propagation state of the history output request time
    #: interval. Possible values are UNSET, SET, and UNCHANGED.
    timeIntervalState: SymbolicConstant = None

    #: An Int specifying the number of intervals during the step at which output database
    #: states are to be written. The default value is 20.
    numIntervals: int = 20

    #: A SymbolicConstant specifying the propagation state of the history output request.
    #: Possible values are UNSET, SET, and UNCHANGED.
    timePointState: SymbolicConstant = None

    #: A SymbolicConstant specifying the propagation state of the history output request.
    #: Possible values are UNSET, SET, and UNCHANGED.
    numIntervalsState: SymbolicConstant = None

    #: A SymbolicConstant specifying the propagation state of the HistoryOutputRequestState
    #: object. Possible values are NOT_YET_ACTIVE, CREATED, PROPAGATED, MODIFIED, DEACTIVATED,
    #: NO_LONGER_ACTIVE, TYPE_NOT_APPLICABLE, and INSTANCE_NOT_APPLICABLE.
    status: SymbolicConstant = None

    #: A tuple of Strings specifying output request variable or component names, or the
    #: SymbolicConstant PRESELECT or ALL. PRESELECT represents all default output variables for
    #: the given step. ALL represents all valid output variables.
    variables: SymbolicConstant = None

    #: The SymbolicConstant ALL or a tuple of Ints specifying a list of eigenmodes for which
    #: output is desired. The default value is ALL.
    modes: SymbolicConstant = ALL

    #: A String specifying the name of a time point object used to determine at which points in
    #: the time period data is written to the output database. The default value is an empty
    #: string.
    timePoint: str = ""

    #: A String specifying a read-only SymbolicConstant describing which type of frequency of
    #: output is used. Possible values areFREQUENCY, NUMBER_INTERVALS, TIME_INTERVAL,
    #: TIME_POINT and MODES. The default value depends on the procedure. The default value is
    #: an empty string.
    frequencyType: str = ""



from ....UtilityAndView.abaqusConstants import *


class ElectricalConductivity:
    r"""The ElectricalConductivity object specifies electrical conductivity.

    .. note:: 
        This object can be accessed by:

        .. code-block:: python

            import material
            mdb.models[name].materials[name].electricalConductivity
            import odbMaterial
            session.odbs[name].materials[name].electricalConductivity

        The table data for this object are:

        - If **type** = ISOTROPIC, the table data specify the following:
        
            - Electrical conductivity.
            - Frequency, if the data depend on frequency.
            - Temperature, if the data depend on temperature.
            - Value of the first field variable, if the data depend on field variables.
            - Value of the second field variable.
            - Etc.
        - If **type** = ORTHOTROPIC, the table data specify the following:
        
            - :math:`\sigma_{11}^{E}`.
            - :math:`\sigma_{22}^{E}`.
            - :math:`\sigma_{33}^{E}`.
            - Frequency, if the data depend on frequency.
            - Temperature, if the data depend on temperature.
            - Value of the first field variable, if the data depend on field variables.
            - Value of the second field variable.
            - Etc.
        - If **type** = ANISOTROPIC, the table data specify the following:
        
            - :math:`\sigma_{11}^{E}`.
            - :math:`\sigma_{12}^{E}`.
            - :math:`\sigma_{22}^{E}`.
            - :math:`\sigma_{13}^{E}`.
            - :math:`\sigma_{23}^{E}`.
            - :math:`\sigma_{33}^{E}`.
            - Frequency, if the data depend on frequency.
            - Temperature, if the data depend on temperature.
            - Value of the first field variable, if the data depend on field variables.
            - Value of the second field variable.
            - Etc.

        The corresponding analysis keywords are:

        - ELECTRICAL CONDUCTIVITY
    """

    def __init__(
        self,
        table: tuple,
        type: SymbolicConstant = ISOTROPIC,
        frequencyDependency: Boolean = OFF,
        temperatureDependency: Boolean = OFF,
        dependencies: int = 0,
    ):
        """This method creates an ElectricalConductivity object.

        .. note:: 
            This function can be accessed by:

            .. code-block:: python

                mdb.models[name].materials[name].ElectricalConductivity
                session.odbs[name].materials[name].ElectricalConductivity

        Parameters
        ----------
        table
            A sequence of sequences of Floats specifying the items described below.
        type
            A SymbolicConstant specifying the type of electrical conductivity. Possible values are
            ISOTROPIC, ORTHOTROPIC, and ANISOTROPIC. The default value is ISOTROPIC.
        frequencyDependency
            A Boolean specifying whether the data depend on frequency. The default value is OFF.
        temperatureDependency
            A Boolean specifying whether the data depend on temperature. The default value is OFF.
        dependencies
            An Int specifying the number of field variable dependencies. The default value is 0.

        Returns
        -------
        ElectricalConductivity
            An :py:class:`~abaqus.Material.Others.Electromagnetic.ElectricalConductivity.ElectricalConductivity` object.

        Raises
        ------
        RangeError
        """
        ...

    def setValues(self, *args, **kwargs):
        """This method modifies the ElectricalConductivity object.

        Raises
        ------
        RangeError
        """
        ...



from .Load import Load
from ..Region.Region import Region
from ..UtilityAndView.abaqusConstants import *


class SubstructureLoad(Load):
    """The SubstructureLoad object defines a substructure load.
    The SubstructureLoad object is derived from the Load object.

    .. note:: 
        This object can be accessed by:

        .. code-block:: python

            import load
            mdb.models[name].loads[name]
    """

    #: A String specifying the load repository key.
    name: str = ""

    #: A :py:class:`~abaqus.Region.Region.Region` object specifying the region to which the load is applied.
    region: Region = Region()

    def __init__(
        self,
        name: str,
        createStepName: str,
        region: Region,
        loadCaseNames: str,
        magnitude: float,
        amplitude: str = UNSET,
    ):
        """This method creates a SubstructureLoad object.

        .. note:: 
            This function can be accessed by:

            .. code-block:: python

                mdb.models[name].SubstructureLoad

        Parameters
        ----------
        name
            A String specifying the load repository key.
        createStepName
            A String specifying the name of the step in which the substructure load is created.
        region
            A :py:class:`~abaqus.Region.Region.Region` object specifying the region to which the load is applied.
        loadCaseNames
            A list of names of the load cases that should be activated by this substructure load.
        magnitude
            A Float specifying the multiplier for the load case magnitude.
        amplitude
            A String or the SymbolicConstant UNSET specifying the name of the amplitude reference.
            UNSET should be used if the load has no amplitude reference. The default value is UNSET.
            You should provide the **amplitude** argument only if it is valid for the specified step.

        Returns
        -------
        SubstructureLoad
            A :py:class:`~abaqus.Load.SubstructureLoad.SubstructureLoad` object.
        """
        super().__init__()

    def setValues(self, amplitude: str = UNSET):
        """This method modifies the data for an existing SubstructureLoad object in the step where
        it is created.

        Parameters
        ----------
        amplitude
            A String or the SymbolicConstant UNSET specifying the name of the amplitude reference.
            UNSET should be used if the load has no amplitude reference. The default value is UNSET.
            You should provide the **amplitude** argument only if it is valid for the specified step.
        """
        ...

    def setValuesInStep(
        self,
        stepName: str,
        loadCaseNames: str = "",
        magnitude: float = None,
        amplitude: str = "",
    ):
        """This method modifies the propagating data for an existing SubstructureLoad object in the
        specified step.

        Parameters
        ----------
        stepName
            A String specifying the name of the step in which the load is modified.
        loadCaseNames
            A list of names of the load cases that should be activated by this substructure load.
        magnitude
            A Float specifying the multiplier for the load case magnitude.
        amplitude
            A String or a SymbolicConstant specifying the name of the amplitude reference. Possible
            values for the SymbolicConstant are UNCHANGED and FREED. UNCHANGED should be used if the
            amplitude is propagated from the previous analysis step. FREED should be used if the
            load has no amplitude reference. You should provide the **amplitude** argument only if it
            is valid for the specified step.
        """
        ...



class DirectDampingByFrequencyComponent:
    """A :py:class:`~abaqus.StepMiscellaneous.DirectDampingByFrequencyComponent.DirectDampingByFrequencyComponent` object is used to define direct damping over a range
    of frequencies.

    .. note:: 
        This object can be accessed by:

        .. code-block:: python

            import step
            mdb.models[name].steps[name].directDampingByFrequency.components[i]
    """

    #: A Float specifying the frequency value in cycles/time.
    frequency: float = None

    #: A Float specifying the fraction of critical damping.
    fraction: float = None



from .Interaction import Interaction
from ..Region.Region import Region
from ..UtilityAndView.abaqusConstants import *


class FilmCondition(Interaction):
    """The FilmCondition object defines film coefficients and associated sink temperatures for
    coupled temperature-displacement analyses.
    The FilmCondition object is derived from the Interaction object.

    .. note:: 
        This object can be accessed by:

        .. code-block:: python

            import interaction
            mdb.models[name].interactions[name]
    """

    #: A String specifying the repository key.
    name: str

    #: A String specifying the name of the step in which the FilmCondition object is created.
    createStepName: str

    #: A :py:class:`~abaqus.Region.Region.Region` object specifying the name of the surface to which the film condition
    #: interaction is applied.
    surface: Region

    #: A SymbolicConstant specifying how the film condition is defined. Possible values are
    #: EMBEDDED_COEFF, PROPERTY_REF, USER_SUB, and FIELD.
    definition: SymbolicConstant

    #: A String specifying the name of the FilmConditionProp object associated with this
    #: interaction. The **interactionProperty** argument applies only when
    #: **definition** = PROPERTY_REF. The default value is an empty string.
    interactionProperty: str = ""

    #: A Float specifying the reference sink temperature, θ0θ0. The default value is 0.0.
    sinkTemperature: float = 0

    #: A String specifying the name of the Amplitude object that gives the variation of the
    #: sink temperature, θ0θ0, with time. The default value is an empty string.Note:Use empty
    #: string in an Abaqus/Standard analysis to specify that the reference sink temperature is
    #: applied immediately at the beginning of the step or linearly over the step. Use empty
    #: string in an Abaqus/Explicit analysis to specify that the reference sink temperature is
    #: applied throughout the step.
    sinkAmplitude: str = ""

    #: A Float specifying the reference film coefficient value, hh. The **filmCoeff** argument
    #: applies when **definition** = EMBEDDED_COEFF, **definition** = USER_SUB, or **definition** = FIELD.
    #: The default value is 0.0.
    filmCoeff: float = 0

    #: A String specifying the name of the Amplitude object that gives the variation of the
    #: film coefficient, hh, with time. The default value is an empty string. Note: Use empty
    #: string in an Abaqus/Standard analysis to specify that the reference film coefficient is
    #: applied immediately at the beginning of the step or linearly over the step. Use empty
    #: string in an Abaqus/Explicit analysis to specify that the reference film coefficient is
    #: applied throughout the step.
    filmCoeffAmplitude: str = ""

    #: A String specifying the name of the AnalyticalField object associated with this
    #: interaction. The **field** argument applies only when **definition** = FIELD. The default
    #: value is an empty string.
    field: str = ""

    #: A String specifying the name of the AnalyticalField or DiscreteField object associated
    #: with the sink temperature. The **sinkFieldName** argument applies only when
    #: **sinkDistributionType** = ANALYTICAL_FIELD or **sinkDistributionType** = DISCRETE_FIELD. The
    #: default value is an empty string.
    sinkFieldName: str = ""

    #: A SymbolicConstant specifying how the sink temperature is distributed. Possible values
    #: are UNIFORM, ANALYTICAL_FIELD, and DISCRETE_FIELD. The default value is UNIFORM.
    sinkDistributionType: SymbolicConstant = UNIFORM

    def __init__(
        self,
        name: str,
        createStepName: str,
        surface: Region,
        definition: SymbolicConstant,
        interactionProperty: str = "",
        sinkTemperature: float = 0,
        sinkAmplitude: str = "",
        filmCoeff: float = 0,
        filmCoeffAmplitude: str = "",
        field: str = "",
        sinkFieldName: str = "",
        sinkDistributionType: SymbolicConstant = UNIFORM,
    ):
        """This method creates a FilmCondition object.

        .. note:: 
            This function can be accessed by:

            .. code-block:: python

                mdb.models[name].FilmCondition

        Parameters
        ----------
        name
            A String specifying the repository key.
        createStepName
            A String specifying the name of the step in which the FilmCondition object is created.
        surface
            A :py:class:`~abaqus.Region.Region.Region` object specifying the name of the surface to which the film condition
            interaction is applied.
        definition
            A SymbolicConstant specifying how the film condition is defined. Possible values are
            EMBEDDED_COEFF, PROPERTY_REF, USER_SUB, and FIELD.
        interactionProperty
            A String specifying the name of the FilmConditionProp object associated with this
            interaction. The **interactionProperty** argument applies only when
            **definition** = PROPERTY_REF. The default value is an empty string.
        sinkTemperature
            A Float specifying the reference sink temperature, θ0θ0. The default value is 0.0.
        sinkAmplitude
            A String specifying the name of the Amplitude object that gives the variation of the
            sink temperature, θ0θ0, with time. The default value is an empty string.Note:Use empty
            string in an Abaqus/Standard analysis to specify that the reference sink temperature is
            applied immediately at the beginning of the step or linearly over the step. Use empty
            string in an Abaqus/Explicit analysis to specify that the reference sink temperature is
            applied throughout the step.
        filmCoeff
            A Float specifying the reference film coefficient value, hh. The **filmCoeff** argument
            applies when **definition** = EMBEDDED_COEFF, **definition** = USER_SUB, or **definition** = FIELD.
            The default value is 0.0.
        filmCoeffAmplitude
            A String specifying the name of the Amplitude object that gives the variation of the
            film coefficient, hh, with time. The default value is an empty string. Note: Use empty
            string in an Abaqus/Standard analysis to specify that the reference film coefficient is
            applied immediately at the beginning of the step or linearly over the step. Use empty
            string in an Abaqus/Explicit analysis to specify that the reference film coefficient is
            applied throughout the step.
        field
            A String specifying the name of the AnalyticalField object associated with this
            interaction. The **field** argument applies only when **definition** = FIELD. The default
            value is an empty string.
        sinkFieldName
            A String specifying the name of the AnalyticalField or DiscreteField object associated
            with the sink temperature. The **sinkFieldName** argument applies only when
            **sinkDistributionType** = ANALYTICAL_FIELD or **sinkDistributionType** = DISCRETE_FIELD. The
            default value is an empty string.
        sinkDistributionType
            A SymbolicConstant specifying how the sink temperature is distributed. Possible values
            are UNIFORM, ANALYTICAL_FIELD, and DISCRETE_FIELD. The default value is UNIFORM.

        Returns
        -------
        FilmCondition
            A :py:class:`~abaqus.Interaction.FilmCondition.FilmCondition` object.
        """
        super().__init__()

    def setValues(
        self,
        interactionProperty: str = "",
        sinkTemperature: float = 0,
        sinkAmplitude: str = "",
        filmCoeff: float = 0,
        filmCoeffAmplitude: str = "",
        field: str = "",
        sinkFieldName: str = "",
        sinkDistributionType: SymbolicConstant = UNIFORM,
    ):
        """This method modifies the data for an existing FilmCondition object in the step where it
        is created.

        Parameters
        ----------
        interactionProperty
            A String specifying the name of the FilmConditionProp object associated with this
            interaction. The **interactionProperty** argument applies only when
            **definition** = PROPERTY_REF. The default value is an empty string.
        sinkTemperature
            A Float specifying the reference sink temperature, θ0θ0. The default value is 0.0.
        sinkAmplitude
            A String specifying the name of the Amplitude object that gives the variation of the
            sink temperature, θ0θ0, with time. The default value is an empty string.Note:Use empty
            string in an Abaqus/Standard analysis to specify that the reference sink temperature is
            applied immediately at the beginning of the step or linearly over the step. Use empty
            string in an Abaqus/Explicit analysis to specify that the reference sink temperature is
            applied throughout the step.
        filmCoeff
            A Float specifying the reference film coefficient value, hh. The **filmCoeff** argument
            applies when **definition** = EMBEDDED_COEFF, **definition** = USER_SUB, or **definition** = FIELD.
            The default value is 0.0.
        filmCoeffAmplitude
            A String specifying the name of the Amplitude object that gives the variation of the
            film coefficient, hh, with time. The default value is an empty string. Note: Use empty
            string in an Abaqus/Standard analysis to specify that the reference film coefficient is
            applied immediately at the beginning of the step or linearly over the step. Use empty
            string in an Abaqus/Explicit analysis to specify that the reference film coefficient is
            applied throughout the step.
        field
            A String specifying the name of the AnalyticalField object associated with this
            interaction. The **field** argument applies only when **definition** = FIELD. The default
            value is an empty string.
        sinkFieldName
            A String specifying the name of the AnalyticalField or DiscreteField object associated
            with the sink temperature. The **sinkFieldName** argument applies only when
            **sinkDistributionType** = ANALYTICAL_FIELD or **sinkDistributionType** = DISCRETE_FIELD. The
            default value is an empty string.
        sinkDistributionType
            A SymbolicConstant specifying how the sink temperature is distributed. Possible values
            are UNIFORM, ANALYTICAL_FIELD, and DISCRETE_FIELD. The default value is UNIFORM.
        """
        ...

    def setValuesInStep(self, stepName: str):
        """This method modifies the propagating data of an existing FilmCondition object in the
        specified step.

        Parameters
        ----------
        stepName
            A String specifying the name of the step in which the interaction is modified.
        """
        ...



from ..Metal.ORNL.Ornl import Ornl
from ..Potential import Potential
from ....UtilityAndView.abaqusConstants import *


class Creep:
    r"""The Creep object defines a creep law.

    .. note:: 
        This object can be accessed by:

        .. code-block:: python

            import material
            mdb.models[name].materials[name].creep
            import odbMaterial
            session.odbs[name].materials[name].creep

        The table data for this object are:

        - If **law** = STRAIN or **law** = TIME, the table data specify the following:
        
            - :math:`A`.
            - :math:`n`.
            - :math:`m`.
            - Temperature, if the data depend on temperature.
            - Value of the first field variable, if the data depend on field variables.
            - Value of the second field variable.
            - Etc.
        - If **law** = HYPERBOLIC_SINE, the table data specify the following:
        
            - :math:`A`.
            - :math:`B`.
            - :math:`n`.
            - :math:`\triangle H`, if the data depend on temperature.
            - :math:`R`
            - Value of the first field variable, if the data depend on field variables.
            - Value of the second field variable.
            - Etc.
        - If **law** = ANAND, the table data specify the following:
        
            - :math:`s_{1}`.
            - :math:`\frac{Q}{R}`.
            - :math:`A`.
            - :math:`\xi`.
            - :math:`m`.
            - :math:`A_{0}`.
            - :math:`\widehat{S}`
            - :math:`n`.
            - :math:`a`.
            - :math:`S_{2}`.
            - :math:`S_{3}`.
            - :math:`A_{1}`.
            - :math:`A_{2}`.
            - :math:`A_{3}`.
            - :math:`A_{4}`.
        - If **law** = DARVEAUX, the table data specify the following:
        
            - :math:`C_{s s}`.
            - :math:`\frac{Q}{R}`.
            - :math:`\alpha`.
            - :math:`n`.
            - :math:`\epsilon_{T}`.
            - :math:`B`.
        - If **law** = DOUBLE_POWER, the table data specify the following:
        
            - :math:`A_{1}`.
            - :math:`B_{1}`.
            - :math:`C_{1}`.
            - :math:`A_{2}`.
            - :math:`B_{2}`.
            - :math:`C_{2}`.
            - :math:`\sigma_{0}`.
        - If **law** = POWER_LAW or **law** = TIME_POWER_LAW, the table data specify the following:
        
            - :math:`q_{0}`
            - :math:`n`.
            - :math:`m`.
            - :math:`\varepsilon_{0}^{\bullet}`.
            - Temperature, if the data depend on temperature.
            - Value of the first field variable, if the data depend on field variables.
            - Value of the second field variable.
            - Etc.

        The corresponding analysis keywords are:

        - CREEP
    """

    #: An :py:class:`~abaqus.Material.Plastic.Metal.ORNL.Ornl.Ornl` object.
    ornl: Ornl = Ornl()

    #: A :py:class:`~abaqus.Material.Plastic.Potential.Potential` object.
    potential: Potential = Potential(((),))

    def __init__(
        self,
        table: tuple,
        law: SymbolicConstant = STRAIN,
        temperatureDependency: Boolean = OFF,
        dependencies: int = 0,
        time: SymbolicConstant = TOTAL,
    ):
        """This method creates a Creep object.

        .. note:: 
            This function can be accessed by:

            .. code-block:: python

                mdb.models[name].materials[name].Creep
                session.odbs[name].materials[name].Creep

        Parameters
        ----------
        table
            A sequence of sequences of Floats specifying the items described below.
        law
            A SymbolicConstant specifying the strain-hardening law. Possible values are STRAIN,
            TIME, HYPERBOLIC_SINE, USER, ANAND, DARVEAUX, DOUBLE_POWER, POWER_LAW, and
            TIME_POWER_LAW. The default value is STRAIN.
        temperatureDependency
            A Boolean specifying whether the data depend on temperature. The default value is OFF.
        dependencies
            An Int specifying the number of field variable dependencies. The default value is 0.
        time
            A SymbolicConstant specifying the time interval for relevant laws. Possible values are
            CREEP and TOTAL. The default value is TOTAL.

        Returns
        -------
        Creep
            A :py:class:`~abaqus.Material.Plastic.Creep.Creep.Creep` object.

        Raises
        ------
        RangeError
        """
        ...

    def setValues(self, *args, **kwargs):
        """This method modifies the Creep object.

        Raises
        ------
        RangeError
        """
        ...



class CombinedTestData:
    r"""The CombinedTestData object specifies simultaneously the normalized shear and bulk
    compliances or relaxation moduli as functions of time.

    .. note:: 
        This object can be accessed by:

        .. code-block:: python

            import material
            mdb.models[name].materials[name].viscoelastic.combinedTestData
            import odbMaterial
            session.odbs[name].materials[name].viscoelastic.combinedTestData

        The table data for this object are:

        If **time** = RELAXATION_TEST_DATA, the table data specify the following:
        
            - Normalized shear modulus, :math:`g_R(t)` (:math:`0\le g_R(t)\le 1`).
            - Normalized volumetric (bulk) modulus, :math:`k_R(t)` (:math:`0\le k_R(t)\le 1`).
            - Time :math:`t` (:math:`t>0`).
        If **time** = CREEP_TEST_DATA, the table data specify the following:
        
            - Normalized shear compliance, :math:`j_S(t)` (:math:`j_S(t)\ge 1`).
            - Normalized volumetric (bulk) compliance, :math:`j_K(t)` (:math:`j_K(t)\ge 1`).
            - Time :math:`t` (:math:`t>0`).

        The corresponding analysis keywords are:

        - COMBINED TEST DATA
    """

    def __init__(self, table: tuple, volinf: float = None, shrinf: float = None):
        """This method creates a CombinedTestData object.

        .. note:: 
            This function can be accessed by:

            .. code-block:: python

                mdb.models[name].materials[name].viscoelastic.CombinedTestData
                session.odbs[name].materials[name].viscoelastic.CombinedTestData

        Parameters
        ----------
        table
            A sequence of sequences of Floats specifying the items described below. The values of
            the table data depend on the value of the **time** member of the Viscoelastic object.
        volinf
            None or a Float specifying a normalized volume. The value of **volinf** depends on the
            value of the **time** member of the Viscoelastic object. The default value is None.
            If **time** = RELAXATION_TEST_DATA, **volinf** specifies the value of the long-term normalized
            volumetric modulus, :math:`k_R(\infty)`.
            If **time** = CREEP_TEST_DATA, **volinf** specifies the value of the long-term normalized
            volumetric compliance, :math:`j_K(\infty)`.
        shrinf
            None or a Float specifying a normalized shear. The value of **shrinf** depends on the
            value of the **time** member of the Viscoelastic object. The default value is None.
            If **time** = RELAXATION_TEST_DATA, **shrinf** specifies the value of the long-term normalized
            shear modulus, :math:`g_R(\infty)`
            If **time** = CREEP_TEST_DATA, **shrinf** specifies the value of the long-term normalized
            shear compliance, :math:`j_S(\infty)`.

        Returns
        -------
        CombinedTestData
            A :py:class:`~abaqus.Material.Elastic.HyperElastic.ViscoElastic.CombinedTestData.CombinedTestData` object.
        """
        ...

    def setValues(self, *args, **kwargs):
        """This method modifies the CombinedTestData object."""
        ...



from .OdbSet import OdbSet


class OdbPretensionSection:
    """The pretension section object is used to define an assembly load. It associates a
    pretension node with a pretension section.

    .. note:: 
        This object can be accessed by:

        .. code-block:: python

            import odbAccess
            session.odbs[name].rootAssembly.pretensionSections[i]
    """

    #: An :py:class:`~abaqus.Odb.OdbSet.OdbSet` object specifying the node set containing the pretension node.
    node: OdbSet = OdbSet("set", ())

    #: An :py:class:`~abaqus.Odb.OdbSet.OdbSet` object specifying the element set that defines the pretension section.
    element: OdbSet = OdbSet("set", ())

    #: An :py:class:`~abaqus.Odb.OdbSet.OdbSet` object specifying the surface set that defines the pretension section.
    surface: OdbSet = OdbSet("set", ())

    #: A tuple of Floats specifying the components of the normal to the pretension section.
    normal: float = None



from ..UtilityAndView.abaqusConstants import *


class Drawing:
    """A drawing is the container for a geometric object. The Drawing object stores the vertex
    data and various settings that determine how the drawing will be displayed.

    .. note:: 
        This object can be accessed by:

        .. code-block:: python

            session.drawings[name]
    """

    #: An Int specifying the number of vertices in the vertex array after a call to the
    #: setVertices method. The default value is 0.
    vertexCount: int = 0

    #: An Int specifying the number of normal vectors in the normal array after a call to the
    #: setNormals method. The default value is 0.
    normalCount: int = 0

    #: An Int specifying the number of colors in the color array after a call to the setColors
    #: method. The default value is 0.
    colorCount: int = 0

    #: A Boolean specifying whether the drawing object will be rendered when referenced. The
    #: default value is OFF.
    show: Boolean = OFF

    #: A Boolean specifying whether polygonal graphics primitives facing away from the viewer
    #: should be culled (not rendered). The default value is OFF.The winding order, and not the
    #: normal, of the graphics primitive is used to determine its facing.
    cullBackfaces: Boolean = OFF

    #: A SymbolicConstant specifying the winding order for polygonal graphics primitives that
    #: face the viewer. Possible values are:CCW, specifying front face winding order is
    #: counter-clockwise.CW, specifying front face winding order is clockwise.The default value
    #: is CCW.
    frontFaceOrder: SymbolicConstant = CCW

    #: A Float specifying the opacity for polygonal graphics primitives. Possible values are
    #: 0.0 ≤ **translucency** ≤ 1.0 with 0.0 being completely transparent (invisible) and 1.0
    #: being opaque. The default value is 1.0.A value greater than 0.3 will cause the
    #: translucent facets to be sorted by depth before being rendered and has the side effect
    #: of disabling two-sided lighting for those facets.
    translucency: float = 1

    #: A Float specifying the width of the line, in millimeters, used to render edges. Possible
    #: values are 0.0 ≤ **lineSize** ≤ 5.0 with 0.0 being interpreted as the thinnest possible
    #: line. The default value is 0.0.A value of 0.0 will be one pixel on the output device.
    #: One pixel on the screen is generally visible but one pixel on a 1200 DPI printer may not
    #: be clear.
    lineSize: float = 0

    #: A Float specifying the width of points, in millimeters, used to render points. Possible
    #: values are 0.0 ≤ **lineSize** ≤ 5.0 with 0.0 being interpreted as the smallest possible
    #: point. The default value is 0.0.A value of 0.0 will be one pixel on the output device.
    #: One pixel on the screen is generally visible but one pixel on a 1200 DPI printer may not
    #: be clear.
    pointSize: float = 0

    #: A Boolean specifying whether the lighting of polygonal graphics primitives is consistent
    #: for each facet or calculated for each displayed pixel. The default value is ON.When
    #: False, only the last normal for each facet will be used in the lighting calculation.
    smoothShade: Boolean = ON

    #: A Boolean specifying whether edge and point drawing commands will be issued in a FILLED
    #: or SHADED display. The default value is ON.If no edge or point drawing commands have
    #: been defined, the polygonal drawing commands will be issued in WIREFRAME and HIDDEN_LINE
    #: displays with the **polygonMode** set to EDGES. If only edge and point drawing commands
    #: have been defined, the Drawing will not be rendered in FILLED or SHADED displays.
    edgesInShaded: Boolean = ON

    #: A tuple of three Floats specifying the **Red**, **Green**, and **Blue** component values for
    #: the edge color. Possible values for each component are between 0.0 and 1.0.
    edgeColor: float = None

    #: A tuple of three Floats specifying the **Red**, **Green**, and **Blue** component values for
    #: the point color. Possible values for each component are between 0.0 and 1.0.
    pointColor: float = None

    #: A String specifying the repository key.
    name: str

    def __init__(self, name: str):
        """This method creates an empty Drawing object.

        .. note:: 
            This function can be accessed by:

            .. code-block:: python

                session.Drawing

        Parameters
        ----------
        name
            A String specifying the repository key.

        Returns
        -------
        Drawing
            A :py:class:`~abaqus.Session.Drawing.Drawing` object.

        Raises
        ------
        ValueError
            - If the user attempts to create a new drawing with the name of an existing drawing:
              ValueError: There is already a drawing with this name
        """
        ...

    def setVertices(self, vertexDimension: float, vertexData: tuple):
        """This method accepts the vertex data that defines the Drawing object. It defines in an
        array of vertices with a length equal to the length of the **vertexData** sequence divided
        by **vertexDimension**.

        Parameters
        ----------
        vertexDimension
            An Integer in the range of 2 to 4 specifying how many Float values are needed to compose
            a single vertex.
        vertexData
            A sequence of Float values that will be used to compose the vertices. There must be
            **vertexDimension** values in the sequence for each vertex.

        Returns
        -------
        The number of vertices described.

        Raises
        ------
        RangeError
            ValueError.
            - If an invalid **vertexDimension** is specified:
              RangeError: **vertexDimension** must be in the range 2 <= value <= 4
            - If **vertexData** is an empty sequence:
              ValueError: **vertexData** cannot be empty.
            - If setVertices has already been called and this call is sending fewer vertices:
              ValueError: **vertexData** cannot be reduced
        """
        ...

    def setNormals(self, normalData: tuple):
        """This method accepts the normal data for each vertex. It defines in an array of normal
        vectors with a length equal to the length of the **normalData** sequence divided by 3.

        Parameters
        ----------
        normalData
            A sequence of Float values that will be used to compose the normals. There must be 3
            values in the sequence for each normal.If only one normal is specified, all vertices
            will use the normal value.

        Returns
        -------
        The number of normals described.

        Raises
        ------
        RangeError
            ValueError.
            - If **normalData** is sequence with less than 3 values:
              ValueError: **normalData** must have at least three values.
            - If setNormals has already been called and this call is sending fewer values:
              ValueError: **normalData** cannot be reduced.
        """
        ...

    def setColors(self, colorDimension: float, colorData: tuple):
        """This method accepts the color data for each vertex. It defines in an array of colors
        with a length equal to the length of the **colorData** sequence divided by
        **colorDimension**.

        Parameters
        ----------
        colorDimension
            An Integer in the range of 3 to 4 specifying how many Float values are needed to compose
            a single color.
        colorData
            A sequence of Float values in the range of 0.0 to 1.0 that will be used to compose the
            colors. There must be **colorDimension** values in the sequence for each color. The first
            color will be associated with the fist vertex and so on.The first Float will be the red
            value for the first color. The second Float will be the green value and the third will
            be the blue value. When **colorDimension** is 4 the 4th Float will be the alpha value for
            the first color but is ignored.If only one color is specified, all vertices will use the
            color value.

        Returns
        -------
        The number of colors described.

        Raises
        ------
        RangeError
            ValueError.
            - If an invalid **colorDimension** is specified:
              RangeError: **colorDimension** must be in the range 3 <= value <= 4
            - If **colorData** is an empty sequence:
              ValueError: **colorData** cannot be empty.
            - If setColors has already been called and this call is sending fewer colors:
              ValueError: **colorData** cannot be reduced
        """
        ...

    def setEdgeColor(self, edgeColor: tuple):
        """This method allows a separate, single color to be used when rendering the edges of the
        drawing. Once called, edges will be rendered using the specified color but facets will
        continue to use the colors specified in the setColors method. An empty sequence can be
        specified to resume using the colors arrays for edges.

        Parameters
        ----------
        edgeColor
            A sequence of 0 or 3 Float values in the range of 0.0 to 1.0 that will be used to
            compose the edge color.If the initial Float value is -1, the viewport background color
            will be used for the edge color.

        Raises
        ------
        ValueError
            - If **edgeColor** is not a sequence of 0 or 3 Floats:
              ValueError: **edgeColor** must be a tuple with 3 values
        """
        ...

    def setPointColor(self, pointColor: tuple):
        """This method allows a separate, single color to be used when rendering the points of the
        drawing. Once called, points will be rendered using the specified color but facets will
        continue to use the colors specified in the setColors method. An empty sequence can be
        specified to resume using the colors arrays for points.

        Parameters
        ----------
        pointColor
            A sequence of 0 or 3 Float values in the range of 0.0 to 1.0 that will be used to
            compose the point color.If the initial Float value is -1, the viewport background color
            will be used for the edge color.

        Raises
        ------
        ValueError
            - If **pointColor** is a not sequence of 0 or 3 Floats:
              ValueError: **pointColor** must be a tuple with 3 values
        """
        ...

    def addArrayDraw(
        self,
        type: SymbolicConstant,
        startIndex: int,
        numVertices: int,
        polygonMode: SymbolicConstant = FILL,
    ):
        """This method adds a rendering command to the drawing and can be called multiple times to
        add additional rendering commands. When the drawing is referenced by a Viewport, the
        drawing commands are used the render the Drawing.
        The rendering command constructs the specified type of geometric primitive using
        **numVertices** array elements starting at element index **startIndex**.

        Parameters
        ----------
        type
            A SymbolicConstant specifying the type of graphics primitive rendered by this command.
            Possible values are POINTS, LINES, LINE_LOOP, LINE_STRIP, TRIANGLES, TRIANGLE_STRIP,
            TRIANGLE_FAN, QUADS, and QUAD_STRIP.
        startIndex
            An Integer specifying the index of the first vertex to render.
        numVertices
            An Integer specifying the total number of vertices to render.
        polygonMode
            A SymbolicConstant specifying how polygonal graphics primitives will be rendered by this
            command. Possible values are FILL, EDGES, and POINTS. The default value is FILL.

        Returns
        -------
        The total number of rendering commands that have been specified.

        Raises
        ------
        ValueError
            - If (**startIndex** + **numVertices** - 1) is larger than the length of the vertex array:
        ValueError: Drawing request extends past array size of vertices.
            - If (**startIndex** + **numVertices** - 1) is larger than the length of the normal array
              and normals are required for the graphics primitive:
              Drawing request extends past array size of normals.
            - If (**startIndex** + **numVertices** - 1) is larger than the length of the color array and
              vertex colors are required for the graphics primitive:
              Drawing request extends past array size of colors.
        """
        ...

    def addIndexDraw(
        self,
        type: SymbolicConstant,
        indices: tuple,
        polygonMode: SymbolicConstant = FILL,
    ):
        """This method adds a rendering command to the drawing and can be called multiple times to
        add additional rendering commands. When the drawing is referenced by a Viewport, the
        drawing commands are used the render the Drawing.
        The rendering command constructs the specified type of geometric primitive using
        **numVertices** array elements starting at element index **startIndex**.

        Parameters
        ----------
        type
            A SymbolicConstant specifying the type of graphics primitive rendered by this command.
            Possible values are POINTS, LINES, LINE_LOOP, LINE_STRIP, TRIANGLES, TRIANGLE_STRIP,
            TRIANGLE_FAN, QUADS, and QUAD_STRIP.
        indices
            A sequence of Integer values specifying index of each vertex to render.
        polygonMode
            A SymbolicConstant specifying how polygonal graphics primitives will be rendered by this
            command. Possible values are FILL, EDGES, and POINTS. The default value is FILL.

        Returns
        -------
        The total number of rendering commands that have been specified.

        Raises
        ------
        ValueError
            - If any value in the **indices** sequence negative:
              ValueError: Index values must be positive.
            - If any value in the **indices** sequence is larger than the length of the vertex array:
        ValueError: Drawing request extends past array size of vertices.
            - If any value in the **indices** sequence is larger than the length of the normal array
              and normals are required for the graphics primitive:
              Drawing request extends past array size of normals.
            - If any value in the **indices** sequence is larger than the length of the color array
              and vertex colors are required for the graphics primitive:
              Drawing request extends past array size of colors.
        """
        ...

    def setValues(
        self,
        show: Boolean = OFF,
        cullBackfaces: Boolean = OFF,
        frontFaceOrder: SymbolicConstant = CCW,
        smoothShade: Boolean = ON,
        edgesInShaded: Boolean = ON,
        translucency: float = 1,
        lineSize: float = 0,
        pointSize: float = 0,
        depthTest: Boolean = ON,
    ):
        """This method modifies the rendering of the Drawing object.

        Parameters
        ----------
        show
            A Boolean specifying whether the drawing object will be rendered when referenced. The
            default value is OFF.
        cullBackfaces
            A Boolean specifying whether polygonal graphics primitives facing away from the viewer
            should be culled (not rendered). The default value is OFF.The winding order, and not the
            normal, of the graphics primitive is used to determine its facing.
        frontFaceOrder
            A SymbolicConstant specifying the winding order for polygonal graphics primitives that
            face the viewer. Possible values are:CCW, specifying front face winding order is
            counter-clockwise.CW, specifying front face winding order is clockwise.The default value
            is CCW.
        smoothShade
            A Boolean specifying whether the lighting of polygonal graphics primitives is consistent
            for each facet or calculated for each displayed pixel. The default value is ON.When
            False, only the last normal for each facet will be used in the lighting calculation.
        edgesInShaded
            A Boolean specifying whether edge and point drawing commands will be issued in a FILLED
            or SHADED display. The default value is ON.If no edge or point drawing commands have
            been defined, the polygonal drawing commands will be issued in WIREFRAME and HIDDEN_LINE
            displays with the **polygonMode** set to EDGES. If only edge and point drawing commands
            have been defined, the Drawing will not be rendered in FILLED or SHADED displays.
        translucency
            A Float specifying the opacity for polygonal graphics primitives. Possible values are
            0.0 ≤ **translucency** ≤ 1.0 with 0.0 being completely transparent (invisible) and 1.0
            being opaque. The default value is 1.0.A value greater than 0.3 will cause the
            translucent facets to be sorted by depth before being rendered and has the side effect
            of disabling two-sided lighting for those facets.
        lineSize
            A Float specifying the width of the line, in millimeters, used to render edges. Possible
            values are 0.0 ≤ **lineSize** ≤ 5.0 with 0.0 being interpreted as the thinnest possible
            line. The default value is 0.0.A value of 0.0 will be one pixel on the output device.
            One pixel on the screen is generally visible but one pixel on a 1200 DPI printer may not
            be clear.
        pointSize
            A Float specifying the width of points, in millimeters, used to render points. Possible
            values are 0.0 ≤ **lineSize** ≤ 5.0 with 0.0 being interpreted as the smallest possible
            point. The default value is 0.0.A value of 0.0 will be one pixel on the output device.
            One pixel on the screen is generally visible but one pixel on a 1200 DPI printer may not
            be clear.
        depthTest
            A Boolean specifying whether an object's depth will be considered during rendering. The
            default value is ON.When OFF, the object will not be hidden by other objects in front of
            it.

        Raises
        ------
        RangeError
            - If an invalid **translucency** value is specified:
              RangeError: **translucency** must be in the range 0.0 <= value <= 1.0
            - If an invalid **lineSize** value is specified:
              RangeError: **lineSize** must be in the range 0.0 <= value <= 5.0
            - If an invalid **pointSize** value is specified:
              RangeError: **pointSize** must be in the range 0.0 <= value <= 5.0
        """
        ...



from ....UtilityAndView.abaqusConstants import *


class Sorption:
    r"""The Sorption object defines absorption and exsorption behaviors of a partially saturated
    porous medium in the analysis of coupled wetting liquid flow and porous medium stress.

    .. note:: 
        This object can be accessed by:

        .. code-block:: python

            import material
            mdb.models[name].materials[name].sorption
            import odbMaterial
            session.odbs[name].materials[name].sorption

        The table data for this object are:

        - If **lawAbsorption** = TABULAR or **lawExsorption** = TABULAR, the **absorptionTable** and **exsorptionTable** data respectively specify the following:

            - Pore pressure, :math:`u_{w}`.
            - Saturation, :math:`\boldsymbol{S}`.

        - If **lawAbsorption** = LOG or **lawExsorption** = LOG, the **absorptionTable** and **exsorptionTable** data respectively specify the following:

            - :math:`A`.
            - :math:`B`.
            - :math:`\boldsymbol{s}_{0}`.
            - :math:`\boldsymbol{s}_{1}`.

        The corresponding analysis keywords are:

        - SORPTION
    """

    def __init__(
        self,
        absorptionTable: tuple,
        lawAbsorption: SymbolicConstant = TABULAR,
        exsorption: Boolean = OFF,
        lawExsorption: SymbolicConstant = TABULAR,
        scanning: float = 0,
        exsorptionTable: tuple = (),
    ):
        r"""This method creates a Sorption object.

        .. note:: 
            This function can be accessed by:

            .. code-block:: python

                mdb.models[name].materials[name].Sorption
                session.odbs[name].materials[name].Sorption

        Parameters
        ----------
        absorptionTable
            A sequence of sequences of Floats specifying the items described below.
        lawAbsorption
            A SymbolicConstant specifying absorption behavior. Possible values are LOG and TABULAR.
            The default value is TABULAR.
        exsorption
            A Boolean specifying whether the exsorption data is specified. The default value is OFF.
        lawExsorption
            A SymbolicConstant specifying exsorption behavior. Possible values are LOG and TABULAR.
            The default value is TABULAR.
        scanning
            A Float specifying the slope of the scanning line, :math:`\left.\left(d u_{w} / d s\right)\right|_{s}`. This slope must be
            positive and larger than the slope of the absorption or exsorption behaviors. The
            default value is 0.0.
        exsorptionTable
            A sequence of sequences of Floats specifying the items described below. The default
            value is an empty sequence.

        Returns
        -------
        Sorption
            A :py:class:`~abaqus.Material.Others.PoreFluidFlow.Sorption.Sorption` object.

        Raises
        ------
        RangeError
        """
        ...

    def setValues(self, *args, **kwargs):
        """This method modifies the Sorption object.

        Raises
        ------
        RangeError
        """
        ...



from .GeometricRestriction import GeometricRestriction
from ..Region.Region import Region
from ..UtilityAndView.abaqusConstants import *


class Growth(GeometricRestriction):
    """The Growth object defines a growth geometric restriction.
    The Growth object is derived from the GeometricRestriction object.

    .. note:: 
        This object can be accessed by:

        .. code-block:: python

            import optimization
            mdb.models[name].optimizationTasks[name].geometricRestrictions[name]
    """

    #: A String specifying the geometric restriction repository key.
    name: str

    #: A :py:class:`~abaqus.Region.Region.Region` object specifying the region to which the geometric restriction is applied.
    #: When used with a TopologyTask, there is no default value. When used with a ShapeTask,
    #: the default value is MODEL.
    region: Region

    #: A Float specifying the maximum optimization displacement in the growth direction. Either
    #: **growth** or **shrink** or both must be specified. The default value is 0.0.
    growth: float = 0

    #: A Boolean specifying whether to ignore the geometric restriction in the first design
    #: cycle. The default value is ON.
    presumeFeasibleRegionAtStart: Boolean = ON

    #: A Float specifying the maximum optimization displacement in the shrink direction. Either
    #: **growth** or **shrink** or both must be specified The default value is 0.0.
    shrink: float = 0

    def __init__(
        self,
        name: str,
        region: Region,
        growth: float = 0,
        presumeFeasibleRegionAtStart: Boolean = ON,
        shrink: float = 0,
    ):
        """This method creates a Growth object.

        .. note:: 
            This function can be accessed by:

            .. code-block:: python

                mdb.models[name].optimizationTasks[name].Growth

        Parameters
        ----------
        name
            A String specifying the geometric restriction repository key.
        region
            A :py:class:`~abaqus.Region.Region.Region` object specifying the region to which the geometric restriction is applied.
            When used with a TopologyTask, there is no default value. When used with a ShapeTask,
            the default value is MODEL.
        growth
            A Float specifying the maximum optimization displacement in the growth direction. Either
            **growth** or **shrink** or both must be specified. The default value is 0.0.
        presumeFeasibleRegionAtStart
            A Boolean specifying whether to ignore the geometric restriction in the first design
            cycle. The default value is ON.
        shrink
            A Float specifying the maximum optimization displacement in the shrink direction. Either
            **growth** or **shrink** or both must be specified The default value is 0.0.

        Returns
        -------
        Growth
            A :py:class:`~abaqus.Optimization.Growth.Growth` object.
        """
        super().__init__()

    def setValues(
        self,
        growth: float = 0,
        presumeFeasibleRegionAtStart: Boolean = ON,
        shrink: float = 0,
    ):
        """This method modifies the Growth object.

        Parameters
        ----------
        growth
            A Float specifying the maximum optimization displacement in the growth direction. Either
            **growth** or **shrink** or both must be specified. The default value is 0.0.
        presumeFeasibleRegionAtStart
            A Boolean specifying whether to ignore the geometric restriction in the first design
            cycle. The default value is ON.
        shrink
            A Float specifying the maximum optimization displacement in the shrink direction. Either
            **growth** or **shrink** or both must be specified The default value is 0.0.
        """
        ...



import typing

from .ConstrainedSketchGeometry import ConstrainedSketchGeometry
from ...UtilityAndView.abaqusConstants import *


class ConstrainedSketchGeometryArray(typing.List[ConstrainedSketchGeometry]):
    """The ConstrainedSketchGeometryArray is a sequence of ConstrainedSketchGeometry objects.

    .. note:: 
        This object can be accessed by:

        .. code-block:: python

            import sketch
            mdb.models[name].sketches[name].geometry[i]
    """

    def findAt(self, coordinates: tuple, printWarning: Boolean = True) -> typing.Union[ConstrainedSketchGeometry, typing.List[ConstrainedSketchGeometry]]:
        """This method returns the ConstrainedSketchGeometry object located at the given
        coordinates.

        Parameters
        ----------
        coordinates
            A sequence of Floats specifying the **X**- and **Y**-coordinates of the object to find.
        printWarning
            A Boolean specifying whether a message is to be printed to the CLI if no entity is found
            at the specified location. The default value is True.

        Returns
        -------
        ConstrainedSketchGeometry
            A :py:class:`~abaqus.Sketcher.ConstrainedSketchGeometry.ConstrainedSketchGeometry.ConstrainedSketchGeometry` object.
        """
        return ConstrainedSketchGeometry()



from .SectionAssignment import SectionAssignment
from ..Assembly.AssemblyBase import AssemblyBase
from ..Region.Set import Set
from ..UtilityAndView.abaqusConstants import *


class PropertyAssembly(AssemblyBase):
    """An :py:class:`~abaqus.Assembly.Assembly.Assembly` object is a container for instances of parts. The Assembly object has no
    constructor command. Abaqus creates the **rootAssembly** member when a Model object is
    created.

    .. note:: 
        This object can be accessed by:

        .. code-block:: python

            import assembly
            mdb.models[name].rootAssembly
    """

    def SectionAssignment(
        self,
        region: Set,
        sectionName: str,
        thicknessAssignment: SymbolicConstant = FROM_SECTION,
        offset: float = 0,
        offsetType: SymbolicConstant = SINGLE_VALUE,
        offsetField: str = "",
    ):
        """This method creates a SectionAssignment object.

        .. note:: 
            This function can be accessed by:

            .. code-block:: python

                mdb.models[name].parts[name].SectionAssignment
                mdb.models[name].rootAssembly.SectionAssignment

        Parameters
        ----------
        region
            A :py:class:`~abaqus.Region.Set.Set` object specifying the region to which the section is assigned.
        sectionName
            A String specifying the name of the section.
        thicknessAssignment
            A SymbolicConstant specifying section thickness assignment method. Possible values are
            FROM_SECTION and FROM_GEOMETRY. The default value is FROM_SECTION.
        offset
            A Float specifying the offset of the shell section. The default value is 0.0.
        offsetType
            A SymbolicConstant specifying the method used to define the shell offset. If
            **offsetType** is set to OFFSET_FIELD the **offsetField** must have a value. Possible values
            are SINGLE_VALUE, MIDDLE_SURFACE, TOP_SURFACE, BOTTOM_SURFACE, FROM_GEOMETRY, and
            OFFSET_FIELD. The default value is SINGLE_VALUE.
        offsetField
            A String specifying the name of the field specifying the offset. The default value is
            "".

        Returns
        -------
        SectionAssignment
            A :py:class:`~abaqus.Property.SectionAssignment.SectionAssignment` object.
        """
        sectionAssignment = SectionAssignment(
            region, sectionName, thicknessAssignment, offset, offsetType, offsetField
        )
        self.sectionAssignments.append(sectionAssignment)
        return sectionAssignment



from .Crack import Crack
from ..Region.Region import Region
from ..UtilityAndView.abaqusConstants import *


class XFEMCrack(Crack):
    """The XFEMCrack object defines the parameters needed to model crack initiation or crack
    growth using XFEM technology. Currently only assembly regions are supported.
    The XFEMCrack object is derived from the Crack object.

    .. note:: 
        This object can be accessed by:

        .. code-block:: python

            import part
            mdb.models[name].parts[name].engineeringFeatures.cracks[name]
            import assembly
            mdb.models[name].rootAssembly.engineeringFeatures.cracks[name]

        The corresponding analysis keywords are:

        - ENRICHMENT
                - INITIAL CONDITIONS
    """

    #: A Boolean specifying whether the crack is suppressed or not. The default value is OFF.
    suppressed: Boolean = OFF

    #: A String specifying the repository key.
    name: str

    #: A :py:class:`~abaqus.Region.Region.Region` object specifying the region that contains the crack or is likely to contain
    #: the crack.
    crackDomain: Region

    #: A Boolean specifying whether the crack is allowed to propagate (grow). The default value
    #: is ON.
    allowCrackGrowth: Boolean = ON

    #: A :py:class:`~abaqus.Region.Region.Region` object specifying the initial crack location. This parameter is required when
    #: *allowCrackGrowth*=OFF.
    crackLocation: Region = None

    #: None or a Float specifying the radius from the crack tips within which the elements are
    #: used for crack singularity calculations. This argument applies only when
    #: *allowCrackGrowth*=OFF. The default value is None.
    singularityCalcRadius: float = None

    #: A String specifying the name of the ContactProperty object that defines the contact
    #: properties for the crack surfaces. The default value is an empty string.
    interactionProperty: str = ""

    #: A sequence of Ints specifying the labels of the elements that are intersected by the
    #: initial crack location. This argument is used only by the input file reader.
    elemId: tuple = ()

    #: A sequence of Ints specifying the position of a node in the corresponding element
    #: connectivity. This argument is used only by the input file reader.
    nodeId: tuple = ()

    #: A sequence of Ints specifying the values indicating the inclusion/exclusion of the
    #: *crackFrontDist* values. A zero value indicates that *crackFrontDist* is not specified
    #: for the ith pair *elemId* and *nodeId*. This argument is used only by the input file
    #: reader.
    hasCrackFront: tuple = ()

    #: A sequence of Floats specifying the values of the first signed distance function. This
    #: argument is used by the input file reader.
    crackPlaneDist: tuple = ()

    #: A sequence of Floats specifying the values of the second signed distance function. This
    #: argument is used only by the input file reader.
    crackFrontDist: tuple = ()

    #: An integer specifying the number of element layers around the crack location, to which
    #: the crack domain is shrunk.
    autoDetectValue: str = ""

    def __init__(
        self,
        name: str,
        crackDomain: Region,
        allowCrackGrowth: Boolean = ON,
        crackLocation: Region = None,
        singularityCalcRadius: float = None,
        interactionProperty: str = "",
        elemId: tuple = (),
        nodeId: tuple = (),
        hasCrackFront: tuple = (),
        crackPlaneDist: tuple = (),
        crackFrontDist: tuple = (),
        autoDetectValue: str = "",
    ):
        """This method creates a XFEMCrack object. Although the constructor is available both for
        parts and for the assembly, XFEMCrack objects are currently supported only under the
        assembly.

        .. note:: 
            This function can be accessed by:

            .. code-block:: python

                mdb.models[name].parts[name].engineeringFeatures.XFEMCrack
                mdb.models[name].rootAssembly.engineeringFeatures.XFEMCrack

        Parameters
        ----------
        name
            A String specifying the repository key.
        crackDomain
            A :py:class:`~abaqus.Region.Region.Region` object specifying the region that contains the crack or is likely to contain
            the crack.
        allowCrackGrowth
            A Boolean specifying whether the crack is allowed to propagate (grow). The default value
            is ON.
        crackLocation
            A :py:class:`~abaqus.Region.Region.Region` object specifying the initial crack location. This parameter is required when
            *allowCrackGrowth*=OFF.
        singularityCalcRadius
            None or a Float specifying the radius from the crack tips within which the elements are
            used for crack singularity calculations. This argument applies only when
            *allowCrackGrowth*=OFF. The default value is None.
        interactionProperty
            A String specifying the name of the ContactProperty object that defines the contact
            properties for the crack surfaces. The default value is an empty string.
        elemId
            A sequence of Ints specifying the labels of the elements that are intersected by the
            initial crack location. This argument is used only by the input file reader.
        nodeId
            A sequence of Ints specifying the position of a node in the corresponding element
            connectivity. This argument is used only by the input file reader.
        hasCrackFront
            A sequence of Ints specifying the values indicating the inclusion/exclusion of the
            *crackFrontDist* values. A zero value indicates that *crackFrontDist* is not specified
            for the ith pair *elemId* and *nodeId*. This argument is used only by the input file
            reader.
        crackPlaneDist
            A sequence of Floats specifying the values of the first signed distance function. This
            argument is used by the input file reader.
        crackFrontDist
            A sequence of Floats specifying the values of the second signed distance function. This
            argument is used only by the input file reader.
        autoDetectValue
            An integer specifying the number of element layers around the crack location, to which
            the crack domain is shrunk.

        Returns
        -------
        XFEMCrack
            A :py:class:`~abaqus.EngineeringFeature.XFEMCrack.XFEMCrack` object.
        """
        super().__init__()

    def setValues(
        self,
        allowCrackGrowth: Boolean = ON,
        crackLocation: Region = None,
        singularityCalcRadius: float = None,
        interactionProperty: str = "",
        elemId: tuple = (),
        nodeId: tuple = (),
        hasCrackFront: tuple = (),
        crackPlaneDist: tuple = (),
        crackFrontDist: tuple = (),
        autoDetectValue: str = "",
    ):
        """This method modifies the XFEMCrack object.

        Parameters
        ----------
        allowCrackGrowth
            A Boolean specifying whether the crack is allowed to propagate (grow). The default value
            is ON.
        crackLocation
            A :py:class:`~abaqus.Region.Region.Region` object specifying the initial crack location. This parameter is required when
            *allowCrackGrowth*=OFF.
        singularityCalcRadius
            None or a Float specifying the radius from the crack tips within which the elements are
            used for crack singularity calculations. This argument applies only when
            *allowCrackGrowth*=OFF. The default value is None.
        interactionProperty
            A String specifying the name of the ContactProperty object that defines the contact
            properties for the crack surfaces. The default value is an empty string.
        elemId
            A sequence of Ints specifying the labels of the elements that are intersected by the
            initial crack location. This argument is used only by the input file reader.
        nodeId
            A sequence of Ints specifying the position of a node in the corresponding element
            connectivity. This argument is used only by the input file reader.
        hasCrackFront
            A sequence of Ints specifying the values indicating the inclusion/exclusion of the
            *crackFrontDist* values. A zero value indicates that *crackFrontDist* is not specified
            for the ith pair *elemId* and *nodeId*. This argument is used only by the input file
            reader.
        crackPlaneDist
            A sequence of Floats specifying the values of the first signed distance function. This
            argument is used by the input file reader.
        crackFrontDist
            A sequence of Floats specifying the values of the second signed distance function. This
            argument is used only by the input file reader.
        autoDetectValue
            An integer specifying the number of element layers around the crack location, to which
            the crack domain is shrunk.
        """
        ...



from ....UtilityAndView.abaqusConstants import *


class ConcreteTensionStiffening:
    r"""The ConcreteTensionStiffening object specifies hardening for the concrete damaged
    plasticity model.

    .. note:: 
        This object can be accessed by:

        .. code-block:: python

            import material
            mdb.models[name].materials[name].concreteDamagedPlasticity.concreteTensionStiffening
            import odbMaterial
            session.odbs[name].materials[name].concreteDamagedPlasticity.concreteTensionStiffening

        The table data for this object are:

        - If **type** = STRAIN, the table data specify the following:
        
            - Remaining direct stress after cracking, :math:`\sigma_{t}`.
            - Direct cracking strain, :math:`\epsilon_{t}^{c k}`.
            - Direct cracking strain rate, :math:`\dot{\epsilon}_{t}^{c k}`.
            - Temperature, if the data depend on temperature.
            - Value of the first field variable, if the data depend on field variables.
            - Value of the second field variable.
            - Etc.
        - If **type** = DISPLACEMENT, the table data specify the following:
        
            - Remaining direct stress after cracking, :math:`\sigma_{t}`.
            - Direct cracking displacement, :math:`u_{t}^{c k}`.
            - Direct cracking displacement rate, :math:`\dot{u}_{t}^{c k}`.
            - Temperature, if the data depend on temperature.
            - Value of the first field variable, if the data depend on field variables.
            - Value of the second field variable.
            - Etc.
        - If **type** = GFI, the table data specify the following:
        
            - Failure stress, :math:`\sigma_{t 0}`
            - Fracture energy, :math:`G_{f}`.
            - Direct cracking displacement rate, :math:`\dot{u}_{t}^{c k}`.
            - Temperature, if the data depend on temperature.
            - Value of the first field variable, if the data depend on field variables.
            - Value of the second field variable.
            - Etc.

        The corresponding analysis keywords are:

        - CONCRETE TENSION STIFFENING
    """

    def __init__(
        self,
        table: tuple,
        rate: Boolean = OFF,
        type: SymbolicConstant = STRAIN,
        temperatureDependency: Boolean = OFF,
        dependencies: int = 0,
    ):
        """This method creates a ConcreteTensionStiffening object.

        .. note:: 
            This function can be accessed by:

            .. code-block:: python

                mdb.models[name].materials[name].concreteDamagedPlasticity.ConcreteTensionStiffening.ConcreteTensionStiffeningials[name].concreteDamagedPlasticity.ConcreteTensionStiffening
            
            Parameters
            ----------
            table
                A sequence of sequences of Floats specifying the items described below. 
            rate
                A Boolean specifying whether the data depend on rate. The default value is OFF. 
            type
                A SymbolicConstant specifying the type of postcracking behavior data. Possible values 
                are: 
                
                - STRAIN, specifying postfailure stress as a function of cracking strain. 
                - DISPLACEMENT, specifying postfailure stress as a function of cracking displacement. 
                - GFI, specifying failure stress as a function of the fracture energy. 
                
                The default value is STRAIN. 
            temperatureDependency
                A Boolean specifying whether the data depend on temperature. The default value is OFF. 
            dependencies
                An Int specifying the number of field variable dependencies. The default value is 0. 

        Returns
        -------
        ConcreteTensionStiffening
            A :py:class:`~abaqus.Material.Plastic.Concrete.ConcreteTensionStiffening.ConcreteTensionStiffening` object. 

        Raises
        ------
        RangeError
        """
        ...

    def setValues(self, *args, **kwargs):
        """This method modifies the ConcreteTensionStiffening object.

        Raises
        ------
        RangeError
        """
        ...



from ..Odb.Odb import Odb
from ..Part.Part import Part
from ..Region.Region import Region


class PlyStackPlot:
    """The PlyStackPlot object is used to plot the stacking of plies in a composite layup or in
    a composite shell section.

    .. note:: 
        This object can be accessed by:

        .. code-block:: python

            import section
            import visualization
    """


def MdbPlyStackPlot(part: Part, region: Region) -> PlyStackPlot:
    """This method creates a PlyStackPlot object from a region of a part that contains a
    composite shell layup.

    .. note:: 
        This function can be accessed by:

        .. code-block:: python

            section.MdbPlyStackPlot

    Parameters
    ----------
    part
        A :py:class:`~abaqus.Part.Part.Part` object.
    region
        A :py:class:`~abaqus.Region.Region.Region` object which contains a composite shell layup.

    Returns
    -------
    PlyStackPlot
        A :py:class:`~abaqus.Property.PlyStackPlot.PlyStackPlot` object.

    Exceptions
    ----------
        None.
    """
    return PlyStackPlot()


def OdbPlyStackPlot(odb: Odb, sectionName: str, offset: float = 0):
    """This method creates a PlyStackPlot object from a composite shell section of an Odb
    object.

    .. note:: 
        This function can be accessed by:

        .. code-block:: python

            visualization.OdbPlyStackPlot

    Parameters
    ----------
    odb
        An :py:class:`~abaqus.Odb.Odb.Odb` object.
    sectionName
        A String specifying the section name that contains a composite shell section.
    offset
        A Float specifying the shell offset. The default value is 0.0.

    Returns
    -------
       A :py:class:`~abaqus.Property.PlyStackPlot.PlyStackPlot` object.

    Exceptions
    ----------
        None.
    """
    return PlyStackPlot()



import typing

from ..Datum.DatumCsys import DatumCsys
from ..UtilityAndView.abaqusConstants import *
from .._OptionsBase import _CopyOptionsBase


class BasicOptions(_CopyOptionsBase):
    """The BasicOptions object stores values and attributes associated with an OdbDisplay
    object.
    The BasicOptions object has no constructor command. Abaqus creates the
    *defaultOdbDisplay.basicOptions* member when you import the Visualization module. Abaqus
    creates a **basicOptions** member when it creates the OdbDisplay object, using the values
    from *defaultOdbDisplay.basicOptions*. Abaqus creates the **odbDisplay** member when a
    viewport is created, using the attributes from the previous active viewport. The
    previous active viewport contains the attributes from the **defaultOdbDisplay** object for
    the session. The attributes from the **defaultOdbDisplay** object are copied from the
    previous active viewport to create the new viewport.
    BasicOptions objects are accessed in one of two ways:

    - The default basic options: these settings are used as defaults when other
      **basicOptions** members are created. These settings can be set to customize user
      preferences.
    - The basic options associated with a particular viewport.

    .. note:: 
        This object can be accessed by:

        .. code-block:: python

            import visualization
            session.defaultOdbDisplay.basicOptions
            session.viewports[name].layers[name].odbDisplay.basicOptions
            session.viewports[name].odbDisplay.basicOptions
    """

    #: A Boolean specifying whether to ignore region boundaries when computing values. The
    #: default value is ON.
    regionAveraging: Boolean = ON

    #: A Boolean specifying whether the camera moves with the coordinate system. The default
    #: value is OFF.
    cameraMovesWithCsys: Boolean = OFF

    #: A Boolean specifying whether the camera, when it moves, follows the rotation of the
    #: coordinate system. The default value is OFF.
    cameraFollowsRotation: Boolean = OFF

    #: A Float specifying the nodal averaging threshold percentage. Possible values are 0 <<
    #: **averagingThreshold** << 100. The default value is 75.0.
    averagingThreshold: float = 75

    #: A SymbolicConstant specifying the quantity to plot. Possible values are FIELD_OUTPUT and
    #: DISCONTINUITIES. The default value is FIELD_OUTPUT.
    quantityToPlot: SymbolicConstant = FIELD_OUTPUT

    #: A SymbolicConstant specifying the extrapolation algorithm. This member is for internal
    #: use only. The only possible value is EXTRAP_COMPUTE_AVERAGE.
    extrapAlgorithm: SymbolicConstant = None

    #: A SymbolicConstant specifying the refinement level for drawing curves. Possible values
    #: are EXTRA_COARSE, COARSE, MEDIUM, FINE, and EXTRA_FINE. The default value is COARSE.
    curveRefinementLevel: SymbolicConstant = COARSE

    #: A Float specifying the feature angle to be used when **visibleEdges** = FEATURE. The default
    #: value is 30.0.
    featureAngle: float = 30

    #: An Int specifying the size of various glyph symbols (boundary conditions, coupling
    #: constraints, etc.). The default value is 6.
    otherSymbolSize: int = 6

    #: A Boolean specifying whether to render the beam profiles. The default value is OFF.
    renderBeamProfiles: Boolean = OFF

    #: A Float specifying the beam profile scale factor. The beamScaleFactor must be greater
    #: than zero. The default value is 1.0.
    beamScaleFactor: float = 1

    #: A Boolean specifying whether to render the shell thickness. The default value is OFF.
    renderShellThickness: Boolean = OFF

    #: A Float specifying the shell thickness scale factor. The shellScaleFactor must be
    #: greater than zero. The default value is 1.0.
    shellScaleFactor: float = 1

    #: A Boolean specifying whether to account for deactivated elements. The default value is
    #: ON.
    accountForDeactivatedElems: Boolean = ON

    #: A Boolean specifying whether to display boundary conditions. The default value is OFF.
    bcDisplay: Boolean = OFF

    #: A Boolean specifying whether to display connectors. The default value is OFF.
    connectorDisplay: Boolean = OFF

    #: A Boolean specifying whether to highlight connector points. The default value is ON.
    highlightConnectorPts: Boolean = ON

    #: A Boolean specifying whether to display connector orientations or coordinate systems.
    #: The default value is ON.
    showConnectorAxes: Boolean = ON

    #: A Boolean specifying whether to display the text that describes the connector type. The
    #: default value is ON.
    showConnectorType: Boolean = ON

    #: A Boolean specifying whether to display point type elements. The default value is ON.
    pointElements: Boolean = ON

    #: A Boolean specifying whether to display reference points. **referencePoints** is valid
    #: only when **pointElements** = ON. The default value is ON.
    referencePoints: Boolean = ON

    #: A Boolean specifying whether to display mass, heat capacity and inertia elements.
    #: **massElements** is valid only when **pointElements** = ON. The default value is OFF.
    massElements: Boolean = OFF

    #: A Boolean specifying whether to display spring and dashpot elements. **springElements** is
    #: valid only when **pointElements** = ON. The default value is OFF.
    springElements: Boolean = OFF

    #: A Boolean specifying whether to display spot weld and distributed coupling elements.
    #: **spotWelds** is valid only when **pointElements** = ON. The default value is OFF.
    spotWelds: Boolean = OFF

    #: A Boolean specifying whether to display tracer particles. **tracerParticles** is valid
    #: only when **pointElements** = ON. The default value is OFF.
    tracerParticles: Boolean = OFF

    #: A Boolean specifying whether to display PC3D elements. **pc3dElements** is valid only when
    #: **pointElements** = ON. The default value is ON.
    pc3dElements: Boolean = ON

    #: A Boolean specifying whether to display PD3D elements. **pd3dElements** is valid only when
    #: **pointElements** = ON. The default value is ON.
    pd3dElements: Boolean = ON

    #: A Boolean specifying whether to sweep the analytical surfaces. The default value is ON
    #: or OFF, depending on the characteristics of your model.
    sweepArs: Boolean = OFF

    #: A Boolean specifying whether to sweep the deformable elements. The default value is ON
    #: or OFF, depending on the characteristics of your model.
    sweepElem: Boolean = OFF

    #: A Float specifying the starting angle (in degrees) from which to sweep the analytical
    #: surfaces when **sweepArs** = ON. The default value is 0.0.
    sweepStartAngleArs: float = 0

    #: A Float specifying the starting angle (in degrees) from which to sweep the model when
    #: **sweepElem** = ON. The default value is 0.0.
    sweepStartAngleElem: float = 0

    #: A Float specifying the angle (in degrees) through which to sweep the analytical surfaces
    #: when **sweepArs** = ON. The default value is 360.0.
    sweepEndAngleArs: float = 360

    #: A Float specifying the angle (in degrees) through which to sweep the model when
    #: **sweepElem** = ON. The default value is 180.0.
    sweepEndAngleElem: float = 180

    #: An Int specifying the number of segments to display when **sweepArs** = ON. The default
    #: value is 10 or 20, depending on characteristics of your model.
    numSweepSegmentsArs: int = None

    #: An Int specifying the number of segments to display when **sweepElem** = ON. The default
    #: value is 10 or 20, depending on characteristics of your model.
    numSweepSegmentsElem: int = None

    #: A SymbolicConstant specifying the numeric form in which to display results that contain
    #: complex numbers. Possible values are COMPLEX_MAGNITUDE, COMPLEX_PHASE, REAL, IMAGINARY,
    #: COMPLEX_MAG_AT_ANGLE, COMPLEX_ENVELOPE_MAX_ABS, COMPLEX_ENVELOPE_MAX, and
    #: COMPLEX_ENVELOPE_MIN. The default value is REAL.
    numericForm: SymbolicConstant = REAL

    #: A Float specifying the angle (in degrees) at which to display results that contain
    #: complex numbers when **numericForm** = COMPLEX_MAG_AT_ANGLE. The default value is 0.0.
    complexAngle: float = 0

    #: A SymbolicConstant specifying which of the section points to use. Possible values are
    #: USE_BOTTOM, USE_TOP, USE_BOTTOM_AND_TOP, and USE_ENVELOPE. The default value is
    #: USE_BOTTOM.
    sectionResults: SymbolicConstant = USE_BOTTOM

    #: A SymbolicConstant specifying the envelope criterion. Possible values are MAX_VALUE,
    #: MIN_VALUE, and MAX_ABS_VALUE. The default value is MAX_ABS_VALUE.
    envelopeCriteria: SymbolicConstant = MAX_ABS_VALUE

    #: A SymbolicConstant specifying the output position for envelope calculations. Possible
    #: values are CENTROID, ELEMENT_NODAL, and INTEGRATION_POINT. The default value is
    #: INTEGRATION_POINT.
    envelopeDataPosition: SymbolicConstant = INTEGRATION_POINT

    #: A SymbolicConstant specifying the ply result location. Possible values are BOTTOM,
    #: MIDDLE, TOP, and TOP_AND_BOTTOM. The default value is MIDDLE.
    plyResultLocation: SymbolicConstant = MIDDLE

    #: A SymbolicConstant specifying the section point scheme. Possible values are
    #: CATEGORY_BASED and PLY_BASED. The default value is CATEGORY_BASED.
    sectionPointScheme: SymbolicConstant = CATEGORY_BASED

    #: A Boolean specifying whether to sweep the cyclic symmetry sectors. The default value is
    #: OFF.
    sweepSectors: Boolean = OFF

    #: A SymbolicConstant specifying how sectors will be selected for sweeping. Possible values
    #: are SELECT_BY_NUMBER, SELECT_BY_ANGLE, and SELECT_ALL. The default value is
    #: SELECT_BY_NUMBER.
    sectorSelectionType: SymbolicConstant = SELECT_BY_NUMBER

    #: A Float specifying the angle (in degrees) from which to sweep cyclic symmetry sectors
    #: when **sweepSectors** = ON. Possible values are multiples of the sector angle such that 0 ≤
    #: **sweepSectorStartAngle** ≤ 360. The default value is 0.0.
    sweepSectorStartAngle: float = 0

    #: A Float specifying the angle (in degrees) through which to sweep cyclic symmetry sectors
    #: when **sweepSectors** = ON. Possible values are multiples of the sector angle such that 0 <<
    #: **sweepSectorEndAngle** ≤ 360. The default value is 360.0.
    sweepSectorEndAngle: float = 360

    #: A Boolean specifying whether to extrude analytical surfaces. The default value is ON or
    #: OFF depending on characteristics of your model.
    extrudeArs: Boolean = OFF

    #: A Boolean specifying whether to use automatic depth determination when extruding
    #: analytical surfaces. The default value is ON. The default value is ON.
    extrudeArsDepthAutoCompute: Boolean = ON

    #: A Boolean specifying whether to extrude deformable elements. The default value is ON or
    #: OFF depending on characteristics of your model.
    extrudeElem: Boolean = OFF

    #: A Float specifying the depth (in model units) by which the analytical surfaces are to be
    #: extruded when **extrudeArs** = ON. The default value is 1.0.
    extrudeArsDepth: float = 1

    #: A Float specifying the depth (in model units) by which the deformable elements are to be
    #: extruded when **extrudeElem** = ON. The default value is 1.0.
    extrudeElemDepth: float = 1

    #: A SymbolicConstant specifying the order of operations to create the mirror pattern.
    #: Possible values are MIRROR_RECT_CIRC, RECT_MIRROR_CIRC, MIRROR_CIRC_RECT,
    #: RECT_CIRC_MIRROR, CIRC_MIRROR_RECT, and CIRC_RECT_MIRROR. The default value is
    #: MIRROR_RECT_CIRC.
    mirrorPatternOrder: SymbolicConstant = MIRROR_RECT_CIRC

    #: A Boolean specifying whether to mirror about the XY plane. The default value is OFF.
    mirrorAboutXyPlane: Boolean = OFF

    #: A Boolean specifying whether to mirror about the XZ plane. The default value is OFF.
    mirrorAboutXzPlane: Boolean = OFF

    #: A Boolean specifying whether to mirror about the YZ plane. The default value is OFF.
    mirrorAboutYzPlane: Boolean = OFF

    #: A Boolean specifying whether to mirror display bodies. The default value is OFF.
    mirrorDisplayBodies: Boolean = OFF

    #: An Int specifying the number of patterns to create in the X-direction for a rectangular
    #: pattern. The default value is 1.
    patternNumX: int = 1

    #: An Int specifying the number of patterns to create in the Y-direction for a rectangular
    #: pattern. The default value is 1.
    patternNumY: int = 1

    #: An Int specifying the number of patterns to create in the Z-direction for a rectangular
    #: pattern. The default value is 1.
    patternNumZ: int = 1

    #: A Float specifying the offset of the pattern along the X-axis for a rectangular pattern.
    #: The default value is 0.0.
    patternOffsetX: float = 0

    #: A Float specifying the offset of the pattern along the Y-axis for a rectangular pattern.
    #: The default value is 0.0.
    patternOffsetY: float = 0

    #: A Float specifying the offset of the pattern along the Z-axis for a rectangular pattern.
    #: The default value is 0.0.
    patternOffsetZ: float = 0

    #: A SymbolicConstant specifying the axis of rotation for a circular. Possible values are
    #: XAXIS, YAXIS, and ZAXIS. The default value is ZAXIS.
    patternRotationAxis: SymbolicConstant = ZAXIS

    #: A Float specifying the total angle of a circular pattern. The default value is 360.0.
    patternTotalAngle: float = 360

    #: An Int specifying the number of patterns to create in a circular pattern. The default
    #: value is 1.
    patternNumCircular: int = 1

    #: A Boolean specifying whether to display coupling constraints. The default value is ON.
    couplingDisplay: Boolean = ON

    #: A Boolean specifying whether to display coordinate systems. The default value is OFF.
    coordSystemDisplay: Boolean = OFF

    #: A Boolean specifying whether to display coordinate systems that represent user-defined
    #: orientations. The default value is OFF.
    scratchCoordSystemDisplay: Boolean = OFF

    #: A SymbolicConstant specifying the transformation to apply to the PrimaryVariable.
    #: Possible values are DEFAULT, NODAL, USER_SPECIFIED, ANGULAR, and LAYUP_ORIENTATION. The
    #: default value is DEFAULT.If **transformationType** = NODAL, Abaqus will transform nodal
    #: vector fields into any orientation defined in the analysis with the TRANSFORM option.
    #: Setting **transformationType** = NODAL has no effect on element-based results.If
    #: **transformationType** = USER_SPECIFIED, Abaqus will transform tensor and vector fields into
    #: the coordinate system specified by **datumCsys**.If
    #: **transformationType** = LAYUP_ORIENTATION, Abaqus will transform tensor and vector fields
    #: into the layup orientation defined in the composite section. The odb should contain the
    #: field SORIENT in order to use this option.
    transformationType: SymbolicConstant = DEFAULT

    #: A Boolean specifying whether to perform a rigid transformation of nodal vector datasets
    #: based on the active user specific system The default value is OFF.
    rigidTransformPrimary: Boolean = OFF

    #: A Boolean specifying whether to perform a rigid transformation of current
    #: deformedVariable based on the active user specific system The default value is OFF.
    rigidTransformDeformed: Boolean = OFF

    #: A Boolean specifying whether to include the effects of deformation on the transformation
    #: calculations The default value is ON.
    transformOnDeformed: Boolean = ON

    #: A Boolean specifying whether the model contains any elements or surfaces that can be
    #: extruded.
    modelCanExtrude: Boolean = OFF

    #: An Int specifying the types of sweepable elements and surfaces contained in the model,
    #: if any.
    sweepModelType: int = None

    #: A Boolean specifying whether to average the element output. The default value is ON.
    averageElementOutput: Boolean = ON

    #: A Boolean specifying whether to average only values on displayed elements. The default
    #: value is ON.
    averageOnlyDisplayed: Boolean = ON

    #: A Boolean specifying whether to average only values on displayed elements. The default
    #: value is ON.
    computeOutput: SymbolicConstant = EXTRAPOLATE_AVERAGE_COMPUTE

    #: A SymbolicConstant specifying the type of averaging region boundaries. Possible values
    #: are NONE, ODB_REGIONS, ELEMENT_SET, and DISPLAY_GROUPS. The default value is
    #: ODB_REGIONS.
    regionBoundaries: SymbolicConstant = ODB_REGIONS

    #: A Boolean specifying whether to use region boundaries when averaging. The default value
    #: is ON.
    useRegionBoundaries: Boolean = ON

    #: A Boolean specifying whether to include additional averaging boundaries for shells and
    #: membranes based on feature edges. The default value is ON.
    includeFeatureBoundaries: Boolean = ON

    #: An Int specifying the number of sectors of a cyclic symmetric model. The value is
    #: automatically computed from the cyclic symmetric model. This value is read-only.
    numSectors: int = None

    #: A Float specifying the sector angle of a cyclic symmetric model. The value is
    #: automatically computed from the cyclic symmetric model. This value is read-only.
    sectorAngle: float = None

    #: A Float specifying the automatic extrude depth used to extrude analytical rigid surfaces
    #: in the default setting. This value is read-only.
    automaticExtrudeDepth: float = None

    #: A String specifying the name of the coordinate system driving the moving camera.
    cameraCsysName: str = ""

    #: A String specifying the color of elements that do not have any results. The default
    #: value is "White".
    noResultsColor: str = ""

    #: The SymbolicConstant GLOBAL or a String specifying the name of the mirror's coordinate
    #: system. The default value is GLOBAL.
    mirrorCsysName: SymbolicConstant = GLOBAL

    #: The SymbolicConstant GLOBAL or a String specifying the name of the pattern's coordinate
    #: system. The default value is GLOBAL.
    patternCsysName: SymbolicConstant = GLOBAL

    #: A :py:class:`~abaqus.Datum.DatumCsys.DatumCsys` object specifying the coordinate system to use for results
    #: transformation
    #: when **transformationType** = USER_SPECIFIED.
    datumCsys: DatumCsys = DatumCsys()

    #: A tuple of Ints specifying which sectors to display when
    #: **sectorSelectionType** = SELECT_BY_NUMBER. Possible values are 1 ≤ **selectedSectorNumbers**
    #: ≤ the number of sectors. The default value is (1).
    selectedSectorNumbers: typing.Tuple[int, ...] = None

    #: A tuple of Strings specifying either element set or display group names (depending on
    #: the value of regionBoundaries) defining the averaging region boundaries. The default
    #: value is an empty sequence.
    userRegions: tuple = ()

    def setValues(
        self,
        options: "BasicOptions" = None,
        *,
        cameraCsysName: str = "",
        cameraMovesWithCsys: Boolean = OFF,
        cameraFollowsRotation: Boolean = OFF,
        averagingThreshold: float = 75,
        quantityToPlot: SymbolicConstant = FIELD_OUTPUT,
        curveRefinementLevel: SymbolicConstant = COARSE,
        noResultsColor: str = "",
        featureAngle: float = 30,
        otherSymbolSize: int = 6,
        renderBeamProfiles: Boolean = OFF,
        beamScaleFactor: float = 1,
        renderShellThickness: Boolean = OFF,
        shellScaleFactor: float = 1,
        accountForDeactivatedElems: Boolean = ON,
        bcDisplay: Boolean = OFF,
        connectorDisplay: Boolean = OFF,
        highlightConnectorPts: Boolean = ON,
        showConnectorAxes: Boolean = ON,
        showConnectorType: Boolean = ON,
        pointElements: Boolean = ON,
        referencePoints: Boolean = ON,
        massElements: Boolean = OFF,
        springElements: Boolean = OFF,
        spotWelds: Boolean = OFF,
        tracerParticles: Boolean = OFF,
        pc3dElements: Boolean = ON,
        pd3dElements: Boolean = ON,
        sweepArs: Boolean = OFF,
        sweepElem: Boolean = OFF,
        sweepStartAngleArs: float = 0,
        sweepStartAngleElem: float = 0,
        sweepEndAngleArs: float = 360,
        sweepEndAngleElem: float = 180,
        numSweepSegmentsArs: int = None,
        numSweepSegmentsElem: int = None,
        numericForm: SymbolicConstant = REAL,
        complexAngle: float = 0,
        sectionResults: SymbolicConstant = USE_BOTTOM,
        envelopeCriteria: SymbolicConstant = MAX_ABS_VALUE,
        envelopeDataPosition: SymbolicConstant = INTEGRATION_POINT,
        plyResultLocation: SymbolicConstant = MIDDLE,
        sectionPointScheme: SymbolicConstant = CATEGORY_BASED,
        sweepSectors: Boolean = OFF,
        sectorSelectionType: SymbolicConstant = SELECT_BY_NUMBER,
        selectedSectorNumbers: typing.Tuple[int, ...] = (),
        sweepSectorStartAngle: float = 0,
        sweepSectorEndAngle: float = 360,
        extrudeArs: Boolean = OFF,
        extrudeArsDepthAutoCompute: Boolean = ON,
        extrudeElem: Boolean = OFF,
        extrudeArsDepth: float = 1,
        extrudeElemDepth: float = 1,
        mirrorPatternOrder: SymbolicConstant = MIRROR_RECT_CIRC,
        mirrorCsysName: SymbolicConstant = GLOBAL,
        mirrorAboutXyPlane: Boolean = OFF,
        mirrorAboutXzPlane: Boolean = OFF,
        mirrorAboutYzPlane: Boolean = OFF,
        mirrorDisplayBodies: Boolean = OFF,
        patternCsysName: SymbolicConstant = GLOBAL,
        patternNumX: int = 1,
        patternNumY: int = 1,
        patternNumZ: int = 1,
        patternOffsetX: float = 0,
        patternOffsetY: float = 0,
        patternOffsetZ: float = 0,
        patternRotationAxis: SymbolicConstant = ZAXIS,
        patternTotalAngle: float = 360,
        patternNumCircular: int = 1,
        couplingDisplay: Boolean = ON,
        coordSystemDisplay: Boolean = OFF,
        scratchCoordSystemDisplay: Boolean = OFF,
        transformationType: SymbolicConstant = DEFAULT,
        datumCsys: DatumCsys = None, 
        rigidTransformPrimary: Boolean = OFF,
        rigidTransformDeformed: Boolean = OFF,
        transformOnDeformed: Boolean = ON,
        averageElementOutput: Boolean = ON,
        averageOnlyDisplayed: Boolean = ON,
        computeOutput: SymbolicConstant = EXTRAPOLATE_AVERAGE_COMPUTE,
        regionBoundaries: SymbolicConstant = ODB_REGIONS,
        useRegionBoundaries: Boolean = ON,
        userRegions: tuple = (),
        includeFeatureBoundaries: Boolean = ON,
    ):
        """This method modifies the BasicOptions object.

        Parameters
        ----------
        options
            A :py:class:`~abaqus.PlotOptions.BasicOptions.BasicOptions` object from which values are to be copied.
            If other arguments are also supplied to setValues, they will override the values in **options**.
            The default value is None.
        cameraCsysName
            A String specifying the name of the coordinate system driving the moving camera.
        cameraMovesWithCsys
            A Boolean specifying whether the camera moves with the coordinate system. The default
            value is OFF.
        cameraFollowsRotation
            A Boolean specifying whether the camera, when it moves, follows the rotation of the
            coordinate system. The default value is OFF.
        averagingThreshold
            A Float specifying the nodal averaging threshold percentage. Possible values are 0 <<
            **averagingThreshold** << 100. The default value is 75.0.
        quantityToPlot
            A SymbolicConstant specifying the quantity to plot. Possible values are FIELD_OUTPUT and
            DISCONTINUITIES. The default value is FIELD_OUTPUT.
        curveRefinementLevel
            A SymbolicConstant specifying the refinement level for drawing curves. Possible values
            are EXTRA_COARSE, COARSE, MEDIUM, FINE, and EXTRA_FINE. The default value is COARSE.
        noResultsColor
            A String specifying the color of elements that do not have any results. The default
            value is "White".
        featureAngle
            A Float specifying the feature angle to be used when **visibleEdges** = FEATURE. The default
            value is 30.0.
        otherSymbolSize
            An Int specifying the size of various glyph symbols (boundary conditions, coupling
            constraints, etc.). The default value is 6.
        renderBeamProfiles
            A Boolean specifying whether to render the beam profiles. The default value is OFF.
        beamScaleFactor
            A Float specifying the beam profile scale factor. The beamScaleFactor must be greater
            than zero. The default value is 1.0.
        renderShellThickness
            A Boolean specifying whether to render the shell thickness. The default value is OFF.
        shellScaleFactor
            A Float specifying the shell thickness scale factor. The shellScaleFactor must be
            greater than zero. The default value is 1.0.
        accountForDeactivatedElems
            A Boolean specifying whether to account for deactivated elements. The default value is
            ON.
        bcDisplay
            A Boolean specifying whether to display boundary conditions. The default value is OFF.
        connectorDisplay
            A Boolean specifying whether to display connectors. The default value is OFF.
        highlightConnectorPts
            A Boolean specifying whether to highlight connector points. The default value is ON.
        showConnectorAxes
            A Boolean specifying whether to display connector orientations or coordinate systems.
            The default value is ON.
        showConnectorType
            A Boolean specifying whether to display the text that describes the connector type. The
            default value is ON.
        pointElements
            A Boolean specifying whether to display point type elements. The default value is ON.
        referencePoints
            A Boolean specifying whether to display reference points. **referencePoints** is valid
            only when **pointElements** = ON. The default value is ON.
        massElements
            A Boolean specifying whether to display mass, heat capacity and inertia elements.
            **massElements** is valid only when **pointElements** = ON. The default value is OFF.
        springElements
            A Boolean specifying whether to display spring and dashpot elements. **springElements** is
            valid only when **pointElements** = ON. The default value is OFF.
        spotWelds
            A Boolean specifying whether to display spot weld and distributed coupling elements.
            **spotWelds** is valid only when **pointElements** = ON. The default value is OFF.
        tracerParticles
            A Boolean specifying whether to display tracer particles. **tracerParticles** is valid
            only when **pointElements** = ON. The default value is OFF.
        pc3dElements
            A Boolean specifying whether to display PC3D elements. **pc3dElements** is valid only when
            **pointElements** = ON. The default value is ON.
        pd3dElements
            A Boolean specifying whether to display PD3D elements. **pd3dElements** is valid only when
            **pointElements** = ON. The default value is ON.
        sweepArs
            A Boolean specifying whether to sweep the analytical surfaces. The default value is ON
            or OFF, depending on the characteristics of your model.
        sweepElem
            A Boolean specifying whether to sweep the deformable elements. The default value is ON
            or OFF, depending on the characteristics of your model.
        sweepStartAngleArs
            A Float specifying the starting angle (in degrees) from which to sweep the analytical
            surfaces when **sweepArs** = ON. The default value is 0.0.
        sweepStartAngleElem
            A Float specifying the starting angle (in degrees) from which to sweep the model when
            **sweepElem** = ON. The default value is 0.0.
        sweepEndAngleArs
            A Float specifying the angle (in degrees) through which to sweep the analytical surfaces
            when **sweepArs** = ON. The default value is 360.0.
        sweepEndAngleElem
            A Float specifying the angle (in degrees) through which to sweep the model when
            **sweepElem** = ON. The default value is 180.0.
        numSweepSegmentsArs
            An Int specifying the number of segments to display when **sweepArs** = ON. The default
            value is 10 or 20, depending on characteristics of your model.
        numSweepSegmentsElem
            An Int specifying the number of segments to display when **sweepElem** = ON. The default
            value is 10 or 20, depending on characteristics of your model.
        numericForm
            A SymbolicConstant specifying the numeric form in which to display results that contain
            complex numbers. Possible values are COMPLEX_MAGNITUDE, COMPLEX_PHASE, REAL, IMAGINARY,
            COMPLEX_MAG_AT_ANGLE, COMPLEX_ENVELOPE_MAX_ABS, COMPLEX_ENVELOPE_MAX, and
            COMPLEX_ENVELOPE_MIN. The default value is REAL.
        complexAngle
            A Float specifying the angle (in degrees) at which to display results that contain
            complex numbers when **numericForm** = COMPLEX_MAG_AT_ANGLE. The default value is 0.0.
        sectionResults
            A SymbolicConstant specifying which of the section points to use. Possible values are
            USE_BOTTOM, USE_TOP, USE_BOTTOM_AND_TOP, and USE_ENVELOPE. The default value is
            USE_BOTTOM.
        envelopeCriteria
            A SymbolicConstant specifying the envelope criterion. Possible values are MAX_VALUE,
            MIN_VALUE, and MAX_ABS_VALUE. The default value is MAX_ABS_VALUE.
        envelopeDataPosition
            A SymbolicConstant specifying the output position for envelope calculations. Possible
            values are CENTROID, ELEMENT_NODAL, and INTEGRATION_POINT. The default value is
            INTEGRATION_POINT.
        plyResultLocation
            A SymbolicConstant specifying the ply result location. Possible values are BOTTOM,
            MIDDLE, TOP, and TOP_AND_BOTTOM. The default value is MIDDLE.
        sectionPointScheme
            A SymbolicConstant specifying the section point scheme. Possible values are
            CATEGORY_BASED and PLY_BASED. The default value is CATEGORY_BASED.
        sweepSectors
            A Boolean specifying whether to sweep the cyclic symmetry sectors. The default value is
            OFF.
        sectorSelectionType
            A SymbolicConstant specifying how sectors will be selected for sweeping. Possible values
            are SELECT_BY_NUMBER, SELECT_BY_ANGLE, and SELECT_ALL. The default value is
            SELECT_BY_NUMBER.
        selectedSectorNumbers
            A sequence of Ints specifying which sectors to display when
            **sectorSelectionType** = SELECT_BY_NUMBER. Possible values are 1 ≤ **selectedSectorNumbers**
            ≤ the number of sectors. The default value is (1).
        sweepSectorStartAngle
            A Float specifying the angle (in degrees) from which to sweep cyclic symmetry sectors
            when **sweepSectors** = ON. Possible values are multiples of the sector angle such that 0 ≤
            **sweepSectorStartAngle** ≤ 360. The default value is 0.0.
        sweepSectorEndAngle
            A Float specifying the angle (in degrees) through which to sweep cyclic symmetry sectors
            when **sweepSectors** = ON. Possible values are multiples of the sector angle such that 0 <<
            **sweepSectorEndAngle** ≤ 360. The default value is 360.0.
        extrudeArs
            A Boolean specifying whether to extrude analytical surfaces. The default value is ON or
            OFF depending on characteristics of your model.
        extrudeArsDepthAutoCompute
            A Boolean specifying whether to use automatic depth determination when extruding
            analytical surfaces. The default value is ON. The default value is ON.
        extrudeElem
            A Boolean specifying whether to extrude deformable elements. The default value is ON or
            OFF depending on characteristics of your model.
        extrudeArsDepth
            A Float specifying the depth (in model units) by which the analytical surfaces are to be
            extruded when **extrudeArs** = ON. The default value is 1.0.
        extrudeElemDepth
            A Float specifying the depth (in model units) by which the deformable elements are to be
            extruded when **extrudeElem** = ON. The default value is 1.0.
        mirrorPatternOrder
            A SymbolicConstant specifying the order of operations to create the mirror pattern.
            Possible values are MIRROR_RECT_CIRC, RECT_MIRROR_CIRC, MIRROR_CIRC_RECT,
            RECT_CIRC_MIRROR, CIRC_MIRROR_RECT, and CIRC_RECT_MIRROR. The default value is
            MIRROR_RECT_CIRC.
        mirrorCsysName
            The SymbolicConstant GLOBAL or a String specifying the name of the mirror's coordinate
            system. The default value is GLOBAL.
        mirrorAboutXyPlane
            A Boolean specifying whether to mirror about the XY plane. The default value is OFF.
        mirrorAboutXzPlane
            A Boolean specifying whether to mirror about the XZ plane. The default value is OFF.
        mirrorAboutYzPlane
            A Boolean specifying whether to mirror about the YZ plane. The default value is OFF.
        mirrorDisplayBodies
            A Boolean specifying whether to mirror display bodies. The default value is OFF.
        patternCsysName
            The SymbolicConstant GLOBAL or a String specifying the name of the pattern's coordinate
            system. The default value is GLOBAL.
        patternNumX
            An Int specifying the number of patterns to create in the X-direction for a rectangular
            pattern. The default value is 1.
        patternNumY
            An Int specifying the number of patterns to create in the Y-direction for a rectangular
            pattern. The default value is 1.
        patternNumZ
            An Int specifying the number of patterns to create in the Z-direction for a rectangular
            pattern. The default value is 1.
        patternOffsetX
            A Float specifying the offset of the pattern along the X-axis for a rectangular pattern.
            The default value is 0.0.
        patternOffsetY
            A Float specifying the offset of the pattern along the Y-axis for a rectangular pattern.
            The default value is 0.0.
        patternOffsetZ
            A Float specifying the offset of the pattern along the Z-axis for a rectangular pattern.
            The default value is 0.0.
        patternRotationAxis
            A SymbolicConstant specifying the axis of rotation for a circular. Possible values are
            XAXIS, YAXIS, and ZAXIS. The default value is ZAXIS.
        patternTotalAngle
            A Float specifying the total angle of a circular pattern. The default value is 360.0.
        patternNumCircular
            An Int specifying the number of patterns to create in a circular pattern. The default
            value is 1.
        couplingDisplay
            A Boolean specifying whether to display coupling constraints. The default value is ON.
        coordSystemDisplay
            A Boolean specifying whether to display coordinate systems. The default value is OFF.
        scratchCoordSystemDisplay
            A Boolean specifying whether to display coordinate systems that represent user-defined
            orientations. The default value is OFF.
        transformationType
            A SymbolicConstant specifying the transformation to apply to the PrimaryVariable.
            Possible values are DEFAULT, NODAL, USER_SPECIFIED, ANGULAR, and LAYUP_ORIENTATION. The
            default value is DEFAULT.If **transformationType** = NODAL, Abaqus will transform nodal
            vector fields into any orientation defined in the analysis with the TRANSFORM option.
            Setting **transformationType** = NODAL has no effect on element-based results.If
            **transformationType** = USER_SPECIFIED, Abaqus will transform tensor and vector fields into
            the coordinate system specified by **datumCsys**.If
            **transformationType** = LAYUP_ORIENTATION, Abaqus will transform tensor and vector fields
            into the layup orientation defined in the composite section. The odb should contain the
            field SORIENT in order to use this option.
        datumCsys
            A :py:class:`~abaqus.Datum.DatumCsys.DatumCsys` object specifying the coordinate system to use for results
            transformation when **transformationType** = USER_SPECIFIED.
        rigidTransformPrimary
            A Boolean specifying whether to perform a rigid transformation of nodal vector datasets
            based on the active user specific system The default value is OFF.
        rigidTransformDeformed
            A Boolean specifying whether to perform a rigid transformation of current
            deformedVariable based on the active user specific system The default value is OFF.
        transformOnDeformed
            A Boolean specifying whether to include the effects of deformation on the transformation
            calculations The default value is ON.
        averageElementOutput
            A Boolean specifying whether to average the element output. The default value is ON.
        averageOnlyDisplayed
            A Boolean specifying whether to average only values on displayed elements. The default
            value is ON.
        computeOutput
            A SymbolicConstant specifying the order or the computations to be performed. Possible
            values are EXTRAPOLATE_AVERAGE_COMPUTE, EXTRAPOLATE_COMPUTE_AVERAGE,
            EXTRAPOLATE_COMPUTE, EXTRAPOLATE_COMPUTE_DISCONTINUITIES, and RAW_DATA. The default
            value is EXTRAPOLATE_AVERAGE_COMPUTE.
        regionBoundaries
            A SymbolicConstant specifying the type of averaging region boundaries. Possible values
            are NONE, ODB_REGIONS, ELEMENT_SET, and DISPLAY_GROUPS. The default value is
            ODB_REGIONS.
        useRegionBoundaries
            A Boolean specifying whether to use region boundaries when averaging. The default value
            is ON.
        userRegions
            A sequence of Strings specifying either element set or display group names (depending on
            the value of regionBoundaries) defining the averaging region boundaries. The default
            value is an empty sequence.
        includeFeatureBoundaries
            A Boolean specifying whether to include additional averaging boundaries for shells and
            membranes based on feature edges. The default value is ON.

        Raises
        ------
        RangeError: featureAngle must be a float in the range 0-90, inclusive
            If **featureAngle** is not in the valid range.
        """
        super().setValues(
            options=options,
            accountForDeactivatedElems=accountForDeactivatedElems,
            averageElementOutput=averageElementOutput,
            averageOnlyDisplayed=averageOnlyDisplayed,
            averagingThreshold=averagingThreshold,
            bcDisplay=bcDisplay,
            beamScaleFactor=beamScaleFactor,
            cameraCsysName=cameraCsysName,
            cameraFollowsRotation=cameraFollowsRotation,
            cameraMovesWithCsys=cameraMovesWithCsys,
            complexAngle=complexAngle,
            computeOutput=computeOutput,
            connectorDisplay=connectorDisplay,
            coordSystemDisplay=coordSystemDisplay,
            couplingDisplay=couplingDisplay,
            curveRefinementLevel=curveRefinementLevel,
            datumCsys=datumCsys,
            envelopeCriteria=envelopeCriteria,
            envelopeDataPosition=envelopeDataPosition,
            extrudeArs=extrudeArs,
            extrudeArsDepth=extrudeArsDepth,
            extrudeArsDepthAutoCompute=extrudeArsDepthAutoCompute,
            extrudeElem=extrudeElem,
            extrudeElemDepth=extrudeElemDepth,
            featureAngle=featureAngle,
            highlightConnectorPts=highlightConnectorPts,
            includeFeatureBoundaries=includeFeatureBoundaries,
            massElements=massElements,
            mirrorAboutXyPlane=mirrorAboutXyPlane,
            mirrorAboutXzPlane=mirrorAboutXzPlane,
            mirrorAboutYzPlane=mirrorAboutYzPlane,
            mirrorCsysName=mirrorCsysName,
            mirrorDisplayBodies=mirrorDisplayBodies,
            mirrorPatternOrder=mirrorPatternOrder,
            noResultsColor=noResultsColor,
            numSweepSegmentsArs=numSweepSegmentsArs,
            numSweepSegmentsElem=numSweepSegmentsElem,
            numericForm=numericForm,
            otherSymbolSize=otherSymbolSize,
            patternCsysName=patternCsysName,
            patternNumCircular=patternNumCircular,
            patternNumX=patternNumX,
            patternNumY=patternNumY,
            patternNumZ=patternNumZ,
            patternOffsetX=patternOffsetX,
            patternOffsetY=patternOffsetY,
            patternOffsetZ=patternOffsetZ,
            patternRotationAxis=patternRotationAxis,
            patternTotalAngle=patternTotalAngle,
            pc3dElements=pc3dElements,
            pd3dElements=pd3dElements,
            plyResultLocation=plyResultLocation,
            pointElements=pointElements,
            quantityToPlot=quantityToPlot,
            referencePoints=referencePoints,
            regionBoundaries=regionBoundaries,
            renderBeamProfiles=renderBeamProfiles,
            renderShellThickness=renderShellThickness,
            rigidTransformDeformed=rigidTransformDeformed,
            rigidTransformPrimary=rigidTransformPrimary,
            scratchCoordSystemDisplay=scratchCoordSystemDisplay,
            sectionPointScheme=sectionPointScheme,
            sectionResults=sectionResults,
            sectorSelectionType=sectorSelectionType,
            selectedSectorNumbers=selectedSectorNumbers,
            shellScaleFactor=shellScaleFactor,
            showConnectorAxes=showConnectorAxes,
            showConnectorType=showConnectorType,
            spotWelds=spotWelds,
            springElements=springElements,
            sweepArs=sweepArs,
            sweepElem=sweepElem,
            sweepEndAngleArs=sweepEndAngleArs,
            sweepEndAngleElem=sweepEndAngleElem,
            sweepSectorEndAngle=sweepSectorEndAngle,
            sweepSectorStartAngle=sweepSectorStartAngle,
            sweepSectors=sweepSectors,
            sweepStartAngleArs=sweepStartAngleArs,
            sweepStartAngleElem=sweepStartAngleElem,
            tracerParticles=tracerParticles,
            transformOnDeformed=transformOnDeformed,
            transformationType=transformationType,
            useRegionBoundaries=useRegionBoundaries,
            userRegions=userRegions,
        )



import typing

from .AdaptivityIteration import AdaptivityIteration
from ..Job.ModelJob import ModelJob
from ..UtilityAndView.abaqusConstants import *


class AdaptivityProcess:
    """The AdaptivityProcess object defines a series of jobs that will be submitted for
    analysis. Abaqus performs adaptive remeshing between each job.

    .. note:: 
        This object can be accessed by:

        .. code-block:: python

            import job
            mdb.adaptivityProcesses[name]
    """

    #: A SymbolicConstant specifying the status of the adaptivity process. Possible values are
    #: SUBMITTED, RUNNING, ABORTED, TERMINATED, and COMPLETED.
    status: SymbolicConstant = None

    #: A repository of AdaptivityIteration objects specifying the AdaptivityIteration objects
    #: received during running the adaptivity process.
    iterations: typing.Dict[int, AdaptivityIteration] = {}

    #: A String specifying the name of the Adaptivity Process.
    name: str

    #: A :py:class:`~abaqus.Job.ModelJob.ModelJob` object specifying a job to be used as the prototype for all analysis jobs run
    #: by the adaptivity process.
    job: ModelJob

    #: An Int specifying the maximum number of analysis jobs that will be run by the Adaptivity
    #: Process. Abaqus performs adaptive remeshing between each analysis. The default value is
    #: 3.
    maxIterations: int = 3

    #: A String specifying the prefix to use for jobs created by the adaptivity process. An
    #: empty string indicates that the name of the adaptivity process should be used. The
    #: default value is an empty string.
    jobPrefix: str = ""

    def __init__(
        self, name: str, job: ModelJob, maxIterations: int = 3, jobPrefix: str = ""
    ):
        """This method creates an AdaptivityProcess object.

        .. note:: 
            This function can be accessed by:

            .. code-block:: python

                mdb.AdaptivityProcess

        Parameters
        ----------
        name
            A String specifying the name of the Adaptivity Process.
        job
            A :py:class:`~abaqus.Job.ModelJob.ModelJob` object specifying a job to be used as the prototype for all analysis jobs run
            by the adaptivity process.
        maxIterations
            An Int specifying the maximum number of analysis jobs that will be run by the Adaptivity
            Process. Abaqus performs adaptive remeshing between each analysis. The default value is
            3.
        jobPrefix
            A String specifying the prefix to use for jobs created by the adaptivity process. An
            empty string indicates that the name of the adaptivity process should be used. The
            default value is an empty string.

        Returns
        -------
        AdaptivityProcess
            An :py:class:`~abaqus.Adaptivity.AdaptivityProcess.AdaptivityProcess` object.

        Raises
        ------
        AbaqusException
        """
        ...

    def submit(
        self,
        waitForCompletion: Boolean = OFF,
        datacheckJob: Boolean = False,
        continueJob: Boolean = False,
    ):
        """This method begins the process of analysis and adaptive remeshing.

        Parameters
        ----------
        waitForCompletion
            A Boolean specifying whether to interrupt the execution of a script until the end of the
            adaptive remeshing process is reached.
        datacheckJob
            A Boolean specifying whether to run the adaptivity as a datacheck analysis. The default
            value is False. The datacheckJob and continueJob arguments cannot both be True.
        continueJob
            A Boolean specifying whether to run the adaptivity as a continuation analysis. The
            default value is False. The datacheckJob and continueJob arguments cannot both be True.
        """
        ...

    def setValues(self, maxIterations: int = 3, jobPrefix: str = ""):
        """This method modifies the AdaptivityProcess object.

        Parameters
        ----------
        maxIterations
            An Int specifying the maximum number of analysis jobs that will be run by the Adaptivity
            Process. Abaqus performs adaptive remeshing between each analysis. The default value is
            3.
        jobPrefix
            A String specifying the prefix to use for jobs created by the adaptivity process. An
            empty string indicates that the name of the adaptivity process should be used. The
            default value is an empty string.
        """
        ...

    def AdaptivityIteration(
        self,
        iteration: int,
        jobName: str,
        modelName: str,
        odbPath: str,
        remeshingErrors: int,
    ) -> AdaptivityIteration:
        """This method creates an AdaptivityIteration object.

        .. note:: 
            This function can be accessed by:

            .. code-block:: python

                mdb.AdaptivityProcess

        Parameters
        ----------
        iteration
            An Int specifying the sequence number for this iteration in the adaptivity process.
        jobName
            A String specifying the name of the job that was run for this iteration.
        modelName
            A String specifying the name of the model that was analyzed and remeshed in this
            iteration.
        odbPath
            A String specifying the path to the ODB file that was created for this iteration.
        remeshingErrors
            An Int specifying the number of part instances which generated errors while remeshing
            the model in this iteration of the adaptivity process.

        Returns
        -------
        AdaptivityIteration
            An :py:class:`~abaqus.Adaptivity.AdaptivityIteration.AdaptivityIteration` object.
        """
        self.iterations[iteration] = iteration = AdaptivityIteration(
            iteration, jobName, modelName, odbPath, remeshingErrors
        )
        return iteration



from ..Adaptivity.AdaptivityModel import AdaptivityModel
from ..Amplitude.AmplitudeModel import AmplitudeModel
from ..Assembly.AssemblyModel import AssemblyModel
from ..BeamSectionProfile.BeamSectionProfileModel import BeamSectionProfileModel
from ..BoundaryCondition.BoundaryConditionModel import BoundaryConditionModel
from ..Calibration.CalibrationModel import CalibrationModel
from ..Constraint.ConstraintModel import ConstraintModel
from ..Filter.FilterModel import FilterModel
from ..Interaction.InteractionModel import InteractionModel
from ..Load.LoadModel import LoadModel
from ..Material.MaterialModel import MaterialModel
from ..Optimization.OptimizationTaskModel import OptimizationTaskModel
from ..Part.PartModel import PartModel
from ..PredefinedField.PredefinedFieldModel import PredefinedFieldModel
from ..Section.SectionModel import SectionModel
from ..Sketcher.SketchModel import SketchModel
from ..Step.StepModel import StepModel
from ..StepOutput.OutputModel import OutputModel


class Model(
    AdaptivityModel,
    AmplitudeModel,
    AssemblyModel,
    BoundaryConditionModel,
    CalibrationModel,
    ConstraintModel,
    FilterModel,
    InteractionModel,
    LoadModel,
    MaterialModel,
    OptimizationTaskModel,
    PartModel,
    PredefinedFieldModel,
    BeamSectionProfileModel,
    OutputModel,
    SectionModel,
    SketchModel,
    StepModel,
):
    """Abaqus creates a Model object named `Model-1` when a session is started.

    .. note:: 
        This object can be accessed by:

        .. code-block:: python

            mdb.models[name]

        The corresponding analysis keywords are:

        - PHYSICAL CONSTANTS
    """

    ...



from .NumberFormat import NumberFormat
from ..UtilityAndView.abaqusConstants import *


class JournalOptions:
    """A :py:class:`~abaqus.Session.JournalOptions.JournalOptions` object specifies how to record selection of geometry in the journal and
    replay files. **journalOptions** can also be used to set the numeric formatting options
    for field report output, geometry commands output, and a default format for other
    numeric output. The JournalOptions object has no constructor. Abaqus creates the
    **journalOptions** member when a session is started.

    .. note:: 
        This object can be accessed by:

        .. code-block:: python

            session.journalOptions
    """

    #: Format of the number
    numberFormat: NumberFormat = NumberFormat()

    def setValues(
        self,
        replayGeometry: SymbolicConstant = COMPRESSEDINDEX,
        recoverGeometry: SymbolicConstant = COMPRESSEDINDEX,
        defaultFormat: NumberFormat = None, 
        fieldReportFormat: NumberFormat = None, 
        geometryFormat: NumberFormat = None, 
    ):
        """This method modifies the JournalOptions object.

        Parameters
        ----------
        replayGeometry
            A SymbolicConstant specifying the format of the geometry in the replay file. Possible
            values are COORDINATE, INDEX, and COMPRESSEDINDEX. The default value is COMPRESSEDINDEX.
        recoverGeometry
            A SymbolicConstant specifying the format of the geometry in the recovery file. Possible
            values are COORDINATE, INDEX, and COMPRESSEDINDEX. The default value is COMPRESSEDINDEX.
        defaultFormat
            A :py:class:`~abaqus.Session.NumberFormat.NumberFormat` object specifying the default format for numeric output. The default
            values are the same as the default values for the NumberFormat object.
        fieldReportFormat
            A :py:class:`~abaqus.Session.NumberFormat.NumberFormat` object specifying the default format for numbers in a field report
            output. The default values are the same as the default values for the NumberFormat
            object.
        geometryFormat
            A :py:class:`~abaqus.Session.NumberFormat.NumberFormat` object specifying the default format for numbers in geometry commands
            output. The default values are the same as the default values for the NumberFormat
            object.
        """
        ...

    def NumberFormat(
        self,
        blankPad: Boolean = ON,
        format: SymbolicConstant = ENGINEERING,
        numDigits: int = 6,
        precision: int = 0,
    ) -> NumberFormat:
        """This method creates a NumberFormat object.

        .. note:: 
            This function can be accessed by:

            .. code-block:: python

                session.defaultFieldReportOptions.NumberFormat
                session.fieldReportOptions.NumberFormat
                session.journalOptions.NumberFormat

        Parameters
        ----------
        blankPad
            A Boolean specifying whether the printed digits should be padded with blank characters
            to ensure equal sized fields. The **blankPad** argument is useful when your printed output
            includes columns. The default value is ON.
        format
            A SymbolicConstant specifying the formatting type. Possible values are ENGINEERING,
            SCIENTIFIC, and AUTOMATIC. The default value is ENGINEERING.
        numDigits
            An Int specifying the number of digits to be displayed in the result. **numDigits** >0>0.
            The default value is 6.
        precision
            An Int specifying the number of decimal places to which the number is to be truncated
            for display. **precision** ≤0≤0. If **precision** =0, no truncation is applied. The default
            value is 0.

        Returns
        -------
        NumberFormat
            A :py:class:`~abaqus.Session.NumberFormat.NumberFormat` object.
        """
        self.numberFormat = numberFormat = NumberFormat(
            blankPad, format, numDigits, precision
        )
        return numberFormat



from .Section import Section


class EulerianSection(Section):
    """The EulerianSection object defines the properties of a Eulerian section.
    The EulerianSection object is derived from the Section object.

    .. note:: 
        This object can be accessed by:

        .. code-block:: python

            import section
            mdb.models[name].sections[name]
            import odbSection
            session.odbs[name].sections[name]

        The corresponding analysis keywords are:

        - EULERIAN SECTION
    """

    #: A String specifying the repository key.
    name: str

    #: A String-to-String Dictionary specifying a dictionary mapping Material instance names to
    #: Material names. Internally the specified mapping gets sorted on Material instance name.
    data: str

    def __init__(self, name: str, data: str):
        """This method creates a EulerianSection object.

        .. note:: 
            This function can be accessed by:

            .. code-block:: python

                mdb.models[name].EulerianSection
                session.odbs[name].EulerianSection

        Parameters
        ----------
        name
            A String specifying the repository key.
        data
            A String-to-String Dictionary specifying a dictionary mapping Material instance names to
            Material names. Internally the specified mapping gets sorted on Material instance name.

        Returns
        -------
        EulerianSection
            An :py:class:`~abaqus.Section.EulerianSection.EulerianSection` object.
        """
        super().__init__()

    def setValues(self, *args, **kwargs):
        """This method modifies the EulerianSection object."""
        ...



from .InteractionState import InteractionState
from ..UtilityAndView.abaqusConstants import *


class FluidInflatorState(InteractionState):
    """The FluidInflatorState object stores the propagating data for a FluidInflator object.
    One instance of this object is created internally by the FluidInflator object for each
    step. The instance is also deleted internally by the FluidInflator object.
    The FluidInflatorState object has no constructor or methods.
    The FluidInflatorState object is derived from the InteractionState object.

    .. note::
        This object can be accessed by:

        .. code-block:: python

            import interaction
            mdb.models[name].steps[name].interactionStates[name]

    """

    #: A *SymbolicConstant* specifying the propagation state of the InteractionState object.
    #: Possible values are:
    #:
    #: - NOT_YET_ACTIVE
    #: - CREATED
    #: - PROPAGATED
    #: - MODIFIED
    #: - DEACTIVATED
    #: - NO_LONGER_ACTIVE
    #: - TYPE_NOT_APPLICABLE
    #: - INSTANCE_NOT_APPLICABLE
    #: - BUILT_INTO_BASE_STATE
    status: SymbolicConstant = None



import typing

from .OdbMeshNode import OdbMeshNode
from .OdbPartBase import OdbPartBase
from .OdbSet import OdbSet
from ..UtilityAndView.abaqusConstants import *


class OdbPart(OdbPartBase):
    def RigidBody(
        self,
        referenceNode: str,
        position: str = INPUT,
        isothermal: Boolean = OFF,
        elset: str = "",
        pinNodes: str = "",
        tieNodes: str = "",
        analyticSurface: str = "",
    ):
        """This method defines an OdbRigidBody on the part object.

        Parameters
        ----------
        referenceNode
            An OdbSet specifying the reference node assigned to the rigid body.
        position
            A symbolic constant specify if the location of the reference node is to be defined by
            the user. Possible values are INPUT and CENTER_OF_MASS. The default value is INPUT.
        isothermal
            A Boolean specifying an isothermal rigid body. The default value is OFF. This parameter
            is used only for a fully-coupled thermal stress analysis.
        elset
            An OdbSet specifying an element set assigned to the rigid body.
        pinNodes
            An OdbSet specifying pin-type nodes assigned to the rigid body.
        tieNodes
            An OdbSet specifying tie-type nodes assigned to the rigid body.
        analyticSurface
            An AnalyticSurface specifying the Analytic Rigid Surface assigned to the rigid body.

        Returns
        -------
        None.

        Raises
        ------
        OdbError: Rigid body definition requires a node set
            If **referenceNode** is not a node set.
        """
        ...

    def NodeSet(self, name: str, nodes: typing.Tuple[OdbMeshNode, ...]) -> OdbSet:
        """This method creates a node set from an array of OdbMeshNode objects (for part
        instance-level sets) or from a sequence of arrays of OdbMeshNode objects (for
        assembly-level sets).

        .. note:: 
            This function can be accessed by:

            .. code-block:: python

                session.odbs[name].parts[name].NodeSet
                session.odbs[name].rootAssembly.instances[name].NodeSet
                session.odbs[name].rootAssembly.NodeSet

        Parameters
        ----------
        name
            A String specifying the name of the set and the repository key.
        nodes
            A sequence of OdbMeshNode objects. For example, for a part:`nodes=part1.nodes[1:5]`For
            an assembly:`nodes=(instance1.nodes[6:7], instance2.nodes[1:5])`

        Returns
        -------
        OdbSet
            An :py:class:`~abaqus.Odb.OdbSet.OdbSet` object.
        """
        self.nodeSets[name] = odbSet = OdbSet(name, nodes)
        return odbSet



import typing

from ..UtilityAndView.abaqusConstants import *
from .._OptionsBase import _OptionsBase


class Movie(_OptionsBase):
    """The Movie object is used to store values and attributes associated with a movie file.
    Upon creation, the Movie object is added to the session.movies repository.

    .. note:: 
        This object can be accessed by:

        .. code-block:: python

            import animation
            session.movies[name]
    """

    #: An Int specifying the width of the movie in pixels.
    width: int = None

    #: An Int specifying the height of the movie in pixels.
    height: int = None

    #: An Int specifying the total number of frames on the movie file.
    numFrames: int = None

    #: A Float specifying the duration of the movie in seconds.
    duration: float = None

    #: An Int specifying the memory taken by the movie frames as selected.
    memory: int = None

    #: A String specifying the repository name for the movie.
    name: str

    #: A String specifying the file from which the movie is to be read. The file extension must
    #: be specified and indicates the movie format (.avi, .mov, .mpeg, or .wmv).
    fileName: str

    #: An Int specifying the first frame to be displayed from this movie. The default value is
    #: 0.
    startFrame: int = 0

    #: An Int specifying the last frame to be displayed from this movie. A negative number will
    #: indicate reverse numbering: -1 is the last frame of the movie. The default value is −1.
    endFrame: int = None

    #: An Int specifying the global timeline frame number that corresponds to **startFrame**. A
    #: value of 0 will indicate the first frame to be displayed in the viewport. The default
    #: value is 0.
    timelineStartFrame: int = 0

    #: An Int specifying the global timeline frame number that corresponds to **endFrame**. A
    #: negative number will indicate reverse numbering: -1 indicates the last frame to be
    #: displayed in the viewport. The default value is −1.
    timelineEndFrame: int = None

    #: A Float specifying the global timeline time that corresponds to the time of
    #: **startFrame**. The default value is 0.0.
    timelineStartTime: float = 0

    #: The SymbolicConstant END_FRAME_TIME or a Float specifying the global timeline time that
    #: corresponds to the time of **endFrame**. The SymbolicConstant END_FRAME_TIME indicates the
    #: time in this movie corresponding to **endFrame**. The default value is END_FRAME_TIME.
    timelineEndTime: typing.Union[SymbolicConstant, float] = END_FRAME_TIME

    def __init__(
        self,
        name: str,
        fileName: str,
        startFrame: int = 0,
        endFrame: int = None,
        timelineStartFrame: int = 0,
        timelineEndFrame: int = None,
        timelineStartTime: float = 0,
        timelineEndTime: typing.Union[SymbolicConstant, float] = END_FRAME_TIME,
    ):
        """This method creates a Movie object from the contents of the specified file.

        .. note:: 
            This function can be accessed by:

            .. code-block:: python

                session.Movie

        Parameters
        ----------
        name
            A String specifying the repository name for the movie.
        fileName
            A String specifying the file from which the movie is to be read. The file extension must
            be specified and indicates the movie format (.avi, .mov, .mpeg, or .wmv).
        startFrame
            An Int specifying the first frame to be displayed from this movie. The default value is
            0.
        endFrame
            An Int specifying the last frame to be displayed from this movie. A negative number will
            indicate reverse numbering: -1 is the last frame of the movie. The default value is −1.
        timelineStartFrame
            An Int specifying the global timeline frame number that corresponds to **startFrame**. A
            value of 0 will indicate the first frame to be displayed in the viewport. The default
            value is 0.
        timelineEndFrame
            An Int specifying the global timeline frame number that corresponds to **endFrame**. A
            negative number will indicate reverse numbering: -1 indicates the last frame to be
            displayed in the viewport. The default value is −1.
        timelineStartTime
            A Float specifying the global timeline time that corresponds to the time of
            **startFrame**. The default value is 0.0.
        timelineEndTime
            The SymbolicConstant END_FRAME_TIME or a Float specifying the global timeline time that
            corresponds to the time of **endFrame**. The SymbolicConstant END_FRAME_TIME indicates the
            time in this movie corresponding to **endFrame**. The default value is END_FRAME_TIME.

        Returns
        -------
        Movie
            A :py:class:`~abaqus.Animation.Movie.Movie` object.

        Raises
        ------
        ValueError: Unable to open movie file
            If **fileName** does not exist or can not be read.
        ValueError: Unsupported movie format
            If **fileName** references an unsupported movie file format.
        ValueError: Unable to decode movie file
            If the contents of **fileName** are corrupt or can not be decoded.
        """
        self.name = name
        self.fileName = fileName
        self.startFrame = startFrame
        self.endFrame = endFrame
        self.timelineStartFrame = timelineStartFrame
        self.timelineEndFrame = timelineEndFrame
        self.timelineStartTime = timelineStartTime
        self.timelineEndTime = timelineEndTime

    def setValues(
        self,
        startFrame: int = 0,
        endFrame: int = None,
        timelineStartFrame: int = 0,
        timelineEndFrame: int = None,
        timelineStartTime: float = 0,
        timelineEndTime: typing.Union[SymbolicConstant, float] = END_FRAME_TIME,
    ):
        """This method modifies the Movie object.

        Parameters
        ----------
        startFrame
            An Int specifying the first frame to be displayed from this movie. The default value is
            0.
        endFrame
            An Int specifying the last frame to be displayed from this movie. A negative number will
            indicate reverse numbering: -1 is the last frame of the movie. The default value is −1.
        timelineStartFrame
            An Int specifying the global timeline frame number that corresponds to **startFrame**. A
            value of 0 will indicate the first frame to be displayed in the viewport. The default
            value is 0.
        timelineEndFrame
            An Int specifying the global timeline frame number that corresponds to **endFrame**. A
            negative number will indicate reverse numbering: -1 indicates the last frame to be
            displayed in the viewport. The default value is −1.
        timelineStartTime
            A Float specifying the global timeline time that corresponds to the time of
            **startFrame**. The default value is 0.0.
        timelineEndTime
            The SymbolicConstant END_FRAME_TIME or a Float specifying the global timeline time that
            corresponds to the time of **endFrame**. The SymbolicConstant END_FRAME_TIME indicates the
            time in this movie corresponding to **endFrame**. The default value is END_FRAME_TIME.

        Raises
        ------
        RangeError: startFrame must be an Integer in the range: 0 to numFrames-1
            If **startFrame**,*endFrame*,*timelineStartFrame*,*timelineEndFrame*,*timelineStartTime*,
            or*timelineEndTime* are outside their respective valid range.
        """
        super().setValues(
            startFrame=startFrame,
            endFrame=endFrame,
            timelineStartFrame=timelineStartFrame,
            timelineEndFrame=timelineEndFrame,
            timelineStartTime=timelineStartTime,
            timelineEndTime=timelineEndTime,
        )



class AbaqusNDarray:
    """The AbaqusNDarray object is a sequence object derived from numpy.ndarray and is used to
    store numeric keyword data from an Abaqus input file. This object is similar to the
    numpy.ndarray object, but the numeric elements are returned as standard Python objects,
    not numpy numeric types.
    The numeric elements can be:
    
    - All ints.
    - All floats.
    - First column int, all other columns floats.
    
    In the last of these cases, the member **colZeroIsInt** will be True; in the other two
    cases, it will be False.

    Notes
    -----
    This object can be accessed by:
    """
    ...



class StructuralDampingComponent:
    """A :py:class:`~abaqus.StepMiscellaneous.StructuralDampingComponent.StructuralDampingComponent` object is used to define structural damping over a range of
    modes.

    .. note:: 
        This object can be accessed by:

        .. code-block:: python

            import step
            mdb.models[name].steps[name].structuralDamping.components[i]
    """

    #: An Int specifying the mode number of the lowest mode of a range.
    start: int = None

    #: An Int specifying the mode number of the highest mode of a range.
    end: int = None

    #: A Float specifying the damping factor, s.
    factor: float = None



from .SolidSection import SolidSection


class HomogeneousSolidSection(SolidSection):
    """The HomogeneousSolidSection object defines the properties of a solid section.
    The HomogeneousSolidSection object is derived from the SolidSection object.

    .. note:: 
        This object can be accessed by:

        .. code-block:: python

            import section
            mdb.models[name].sections[name]
            import odbSection
            session.odbs[name].sections[name]

        The corresponding analysis keywords are:

        - SOLID SECTION
    """

    #: A String specifying the repository key.
    name: str

    #: A String specifying the name of the material.
    material: str

    #: A Float specifying the thickness of the section. Possible values are None or greater
    #: than zero. The default value is 1.0.
    thickness: float = None

    def __init__(self, name: str, material: str, thickness: float = None):
        """This method creates a HomogeneousSolidSection object.

        .. note:: 
            This function can be accessed by:

            .. code-block:: python

                mdb.models[name].HomogeneousSolidSection
                session.odbs[name].HomogeneousSolidSection

        Parameters
        ----------
        name
            A String specifying the repository key.
        material
            A String specifying the name of the material.
        thickness
            A Float specifying the thickness of the section. Possible values are None or greater
            than zero. The default value is 1.0.

        Returns
        -------
        HomogeneousSolidSection
            A :py:class:`~abaqus.Section.HomogeneousSolidSection.HomogeneousSolidSection` object.

        Raises
        ------
        InvalidNameError
        RangeError
        """
        super().__init__()

    def setValues(self, thickness: float = 1):
        """This method modifies the HomogeneousSolidSection object.

        Parameters
        ----------
        thickness
            A Float specifying the thickness of the section. Possible values are None or greater
            than zero. The default value is 1.0.

        Raises
        ------
        RangeError
        """
        ...



class ModelDot:
    """The ModelDot object can be used to access an actual MeshNode, ReferencePoint, or ConstrainedSketchVertex
    object.

    Notes
    -----
    This object can be accessed by:
    """

    ...



class ContactInitialization:
    """The ContactInitialization object is the abstract base type for other
    ContactInitialization objects. The ContactInitialization object has no explicit
    constructor, members, or methods.

    .. note:: 
        This object can be accessed by:

        .. code-block:: python

            import interaction
            mdb.models[name].contactInitializations[name]
    """

    ...



import typing

from .AreaStyle import AreaStyle
from .LineStyle import LineStyle
from ..UtilityAndView.abaqusConstants import *


class Area:
    """The Area object is used to display a rectangular area in an XYPlot. The Area object has
    no constructor. Area objects are automatically created whenever a XYPlot, Chart,
    PlotTitle, or Legend objects are created.

    .. note:: 
        This object can be accessed by:

        .. code-block:: python

            import visualization
            session.charts[name].area
            session.charts[name].gridArea
            session.charts[name].legend.area
            session.defaultChartOptions.gridArea
            session.defaultChartOptions.legend.area
            session.defaultPlot.area
            session.defaultPlot.title.area
            session.xyPlots[name].area
            session.xyPlots[name].charts[name].area
            session.xyPlots[name].charts[name].gridArea
            session.xyPlots[name].charts[name].legend.area
            session.xyPlots[name].title.area
    """

    #: A Boolean specifying whether the area is inset or occupies a reserved area. The default
    #: value is OFF.
    inset: Boolean = OFF

    #: A SymbolicConstant specifying how the area is positioned. Possible values are AUTO_ALIGN
    #: and MANUAL. The default value is AUTO_ALIGN.
    positionMethod: SymbolicConstant = AUTO_ALIGN

    #: A SymbolicConstant specifying the relative position of the area in its parent when
    #: **positionMethod** = AUTO_ALIGN. Possible values are:
    #: 
    #: - BOTTOM_LEFT
    #: - BOTTOM_CENTER
    #: - BOTTOM_RIGHT
    #: - CENTER_LEFT
    #: - CENTER
    #: - CENTER_RIGHT
    #: - TOP_LEFT
    #: - TOP_CENTER
    #: - TOP_RIGHT
    #: The default value is BOTTOM_LEFT.
    alignment: SymbolicConstant = BOTTOM_LEFT

    #: A SymbolicConstant specifying how the area size is defined. Possible values are
    #: AUTOMATIC and MANUAL. The default value is AUTOMATIC.
    sizeMethod: SymbolicConstant = AUTOMATIC

    #: A Float specifying the width of the area in mm. The default value is 1.0.
    width: float = 1

    #: A Float specifying the height of the area in mm. The default value is 1.0.
    height: float = 1

    #: A Float specifying the scale as a fraction of the width of the available area when the
    #: sizeMethod=MANUAL. The valid range is (0, 1). The default value is 1.0.
    widthScale: float = 1

    #: A Float specifying the scale as a fraction of the height of the available area when the
    #: **sizeMethod** = MANUAL. The valid range is (0, 1). The default value is 1.0.
    heightScale: float = 1

    #: A Float specifying the left padding of the area in mm. The default value is 1.0.
    pl: float = 1

    #: A Float specifying the right padding of the area in mm. The default value is 1.0.
    pr: float = 1

    #: A Float specifying the top padding of the area in mm. The default value is 1.0.
    pt: float = 1

    #: A Float specifying the bottom padding of the area in mm. The default value is 1.0.
    pb: float = 1

    #: An :py:class:`~abaqus.XY.AreaStyle.AreaStyle` object specifying whether and how to fill the area.
    style: AreaStyle = AreaStyle()

    #: A :py:class:`~abaqus.XY.LineStyle.LineStyle` object specifying whether and how to draw the border of the area.
    border: LineStyle = LineStyle()

    #: A pair of Floats specifying the X- and Y-offsets in millimeters from the lower-left
    #: corner of the XYPlot.
    origin: typing.Tuple[float, ...] = ()

    #: A pair of Floats specifying the X- and Y-offsets of the origin as a fraction of the
    #: available area. The **originOffset** argument is ignored unless **positionMethod** = MANUAL.
    #: The default value is (-1, 0). The valid range for each float is (0, 1).
    originOffset: typing.Tuple[float, ...] = ()

    def setValues(
        self,
        area: "Area",
        style: AreaStyle,
        border: LineStyle,
        positionMethod: SymbolicConstant = AUTO_ALIGN,
        alignment: SymbolicConstant = BOTTOM_LEFT,
        sizeMethod: SymbolicConstant = AUTOMATIC,
        originOffset: typing.Tuple[float, ...] = (),
        widthScale: float = 1,
        heightScale: float = 1,
        inset: Boolean = OFF,
        pl: float = 1,
        pr: float = 1,
        pt: float = 1,
        pb: float = 1,
    ):
        """This method modifies the Area object.

        Parameters
        ----------
        area
            An :py:class:`~abaqus.XY.Area.Area` object from which attributes are to be copied.
        style
            An :py:class:`~abaqus.XY.AreaStyle.AreaStyle` object.
        border
            A :py:class:`~abaqus.XY.LineStyle.LineStyle` object.
        positionMethod
            A SymbolicConstant specifying how the area is positioned. Possible values are AUTO_ALIGN
            and MANUAL. The default value is AUTO_ALIGN.
        alignment
            A SymbolicConstant specifying the relative position of the area in its parent when
            **positionMethod** = AUTO_ALIGN. Possible values are:

            - BOTTOM_LEFT
            - BOTTOM_CENTER
            - BOTTOM_RIGHT
            - CENTER_LEFT
            - CENTER
            - CENTER_RIGHT
            - TOP_LEFT
            - TOP_CENTER
            - TOP_RIGHT
            
            The default value is BOTTOM_LEFT.
        sizeMethod
            A SymbolicConstant specifying how the area size is defined. Possible values are
            AUTOMATIC and MANUAL. The default value is AUTOMATIC.
        originOffset
            A pair of Floats specifying the X- and Y-offsets of the origin as a fraction of the
            available area. The **originOffset** argument is ignored unless **positionMethod** = MANUAL.
            The default value is (-1, 0). The valid range for each float is (0, 1).
        widthScale
            A Float specifying the scale as a fraction of the width of the available area when the
            sizeMethod=MANUAL. The valid range is (0, 1). The default value is 1.0.
        heightScale
            A Float specifying the scale as a fraction of the height of the available area when the
            **sizeMethod** = MANUAL. The valid range is (0, 1). The default value is 1.0.
        inset
            A Boolean specifying whether the area is inset or occupies a reserved area. The default
            value is OFF.
        pl
            A Float specifying the left padding of the area in mm. The default value is 1.0.
        pr
            A Float specifying the right padding of the area in mm. The default value is 1.0.
        pt
            A Float specifying the top padding of the area in mm. The default value is 1.0.
        pb
            A Float specifying the bottom padding of the area in mm. The default value is 1.0.

        Raises
        ------
        RangeError
        """
        ...



from .CommandRegister import CommandRegister


class RegisteredTuple(CommandRegister, tuple):
    """This class allows you to create a tuple that can be queried from the GUI and is capable
    of notifying the GUI when the contents of any of the tuple's members change.
    The RegisteredTuple object is derived from the CommandRegister object.

    .. note:: 
        This object can be accessed by:

        .. code-block:: python

            import customKernel
    """

    def __init__(self, tuple: tuple):
        """This method creates a RegisteredTuple object.

        .. note:: 
            This function can be accessed by:

            .. code-block:: python

                customKernel.RegisteredTuple

        Parameters
        ----------
        tuple
            A tuple of objects. These objects must be derived from the CommandRegister class.

        Returns
        -------
        RegisteredTuple
            A :py:class:`~abaqus.CustomKernel.RegisteredTuple.RegisteredTuple` object.
        """
        super().__init__()

    def Methods(self):
        """The RegisteredTuple object supports the same methods as a standard Python list object."""
        # TODO: Implement this method
        ...



from .LoadState import LoadState
from ..UtilityAndView.abaqusConstants import *


class SubmodelSBState(LoadState):
    """The SubmodelSBState object stores the propagating data for a Submodel load in a step.
    One instance of this object is created internally by the SubmodelSB object for each
    step. The instance is also deleted internally by the SubmodelSB object.
    The SubmodelSBState object has no constructor or methods.
    The SubmodelSBState object is derived from the LoadState object.

    .. note:: 
        This object can be accessed by:

        .. code-block:: python

            import load
            mdb.models[name].steps[name].loadStates[name]

        The corresponding analysis keywords are:

        - SUBMODEL
                - DSLOAD
    """

    #: A SymbolicConstant specifying the propagation state of the **globalStep** member. Possible
    #: values are SET and UNCHANGED.
    globalStepState: SymbolicConstant = None

    #: An Int specifying the increment number in the global model step at which the solution
    #: will be used to specify the values of the driven variables. This argument is applicable
    #: only for linear perturbation steps.
    globalIncrement: int = None

    #: A SymbolicConstant specifying the propagation state of the **globalIncrement** member.
    #: Possible values are SET and UNCHANGED.
    globalIncrementState: SymbolicConstant = None

    #: A String specifying the step in the global model from which Abaqus reads the values of
    #: the variables that will drive the submodel analysis. The String indicates the position
    #: of the step in the sequence of analysis steps. For example, **globalStep** = '1' indicates
    #: the first step.
    globalStep: str = ""

    #: A SymbolicConstant specifying the propagation state of the **amplitude** member. Possible
    #: values are UNSET, SET, UNCHANGED, and FREED.
    amplitudeState: SymbolicConstant = None

    #: A SymbolicConstant specifying the propagation state of the LoadState object. Possible
    #: values are:
    #: 
    #: - NOT_YET_ACTIVE
    #: - CREATED
    #: - PROPAGATED
    #: - MODIFIED
    #: - DEACTIVATED
    #: - NO_LONGER_ACTIVE
    #: - TYPE_NOT_APPLICABLE
    #: - INSTANCE_NOT_APPLICABLE
    #: - BUILT_INTO_BASE_STATE
    status: SymbolicConstant = None

    #: A String specifying the name of the amplitude reference. The String is empty if the load
    #: has no amplitude reference.
    amplitude: str = ""



from .Section import Section


class AcousticInfiniteSection(Section):
    """The AcousticInfiniteSection object defines the properties of an acoustic section.
    The AcousticInfiniteSection object is derived from the Section object.

    .. note:: 
        This object can be accessed by:

        .. code-block:: python

            import section
            mdb.models[name].sections[name]
            import odbSection
            session.odbs[name].sections[name]

        The corresponding analysis keywords are:

        - SOLID SECTION
    """

    #: A String specifying the repository key.
    name: str

    #: A String specifying the name of the material.
    material: str

    #: A Float specifying the thickness of the section. Possible values are **thickness** >> 0.0.
    #: The default value is 1.0.
    thickness: float = 1

    #: An Int specifying the number of ninth-order polynomials that will be used to resolve the
    #: variation of the acoustic field in the infinite direction. Possible values are 0 <<
    #: **order** ≤≤ 10. The default value is 10.
    order: int = 10

    def __init__(self, name: str, material: str, thickness: float = 1, order: int = 10):
        """This method creates an AcousticInfiniteSection object.

        .. note:: 
            This function can be accessed by:

            .. code-block:: python

                mdb.models[name].AcousticInfiniteSection
                session.odbs[name].AcousticInfiniteSection

        Parameters
        ----------
        name
            A String specifying the repository key.
        material
            A String specifying the name of the material.
        thickness
            A Float specifying the thickness of the section. Possible values are **thickness** >> 0.0.
            The default value is 1.0.
        order
            An Int specifying the number of ninth-order polynomials that will be used to resolve the
            variation of the acoustic field in the infinite direction. Possible values are 0 <<
            **order** ≤≤ 10. The default value is 10.

        Returns
        -------
        AcousticInfiniteSection
            An :py:class:`~abaqus.Section.AcousticInfiniteSection.AcousticInfiniteSection` object.

        Raises
        ------
        InvalidNameError
        RangeError
        """
        super().__init__()

    def setValues(self, thickness: float = 1, order: int = 10):
        """This method modifies the AcousticInfiniteSection object.

        Parameters
        ----------
        thickness
            A Float specifying the thickness of the section. Possible values are **thickness** >> 0.0.
            The default value is 1.0.
        order
            An Int specifying the number of ninth-order polynomials that will be used to resolve the
            variation of the acoustic field in the infinite direction. Possible values are 0 <<
            **order** ≤≤ 10. The default value is 10.

        Raises
        ------
        RangeError
        """
        ...



import typing

from .Annotation import Annotation


class AnnotationsToPlotArray(typing.List[Annotation]):
    """The AnnotationsToPlotArray object is a sequence that stores references to plotted
    annotations. By adding annotations to and removing annotations from this sequence, you
    can control which annotations are displayed in a particular viewport.

    .. note:: 
        This object can be accessed by:

        .. code-block:: python

            import annotationToolset
            session.viewports[name].annotationsToPlot
    """

    def bringForward(self, index: str):
        """This method brings the Annotation object one position forward in the
        AnnotationsToPlotArray sequence.

        Parameters
        ----------
        index
            An Int specifying the index of the Annotation object in the AnnotationsToPlotArray
            sequence.

        """
        # TODO: implement this method
        ...

    def bringToFront(self, index: str):
        """This method brings the Annotation object to the beginning of the AnnotationsToPlotArray
        sequence.

        Parameters
        ----------
        index
            An Int specifying the index of the Annotation object in the AnnotationsToPlotArray
            sequence.

        """
        # TODO: implement this method
        ...

    def moveAfter(self, index: str, other: str):
        """This method moves the Annotation object after another object in the same
        AnnotationsToPlotArray sequence.

        Parameters
        ----------
        index
            An Integer specifying the index of the Annotation object in the AnnotationsToPlotArray
            sequence.
        other
            An Integer specifying the index of the other Annotation object in the
            AnnotationsToPlotArray sequence after which this object will be moved.

        """
        # TODO: implement this method
        ...

    def moveBefore(self, index: str, other: str):
        """This method moves the Annotation object before another object in the same
        AnnotationsToPlotArray sequence.

        Parameters
        ----------
        index
            An Int specifying the index of the Annotation object in the AnnotationsToPlotArray
            sequence.
        other
            An Int specifying the index of the other Annotation object in the AnnotationsToPlotArray
            sequence before which this object will be moved.

        """
        # TODO: implement this method
        ...

    def sendBackward(self, index: str):
        """This method sends the Annotation object one position backward in the
        AnnotationsToPlotArray sequence.

        Parameters
        ----------
        index
            An Int specifying the index of the Annotation object in the AnnotationsToPlotArray
            sequence.

        """
        # TODO: implement this method
        ...

    def sendToBack(self, index: str):
        """This method sends the Annotation object to the end of the AnnotationsToPlotArray
        sequence.

        Parameters
        ----------
        index
            An Int specifying the index of the Annotation object in the AnnotationsToPlotArray
            sequence.

        """
        # TODO: implement this method
        ...
